window.Gleam.initSearch([{"doc":"gtempo","title":"gtempo","content":"# Tempo\n\nA gleam library for controlling the tempo of your application through helpful date and time functions!\n\nOnly run a task past a certain time of day, only accept submissions since a certain date, calculate the difference beteen times and dates, time long running tasks, parse and format datetimes, and more. Over 262 unit tests, contributions welcome!\n\nWritten in almost pure Gleam, Tempo tries to optimize for the same thing the Gleam language does: explicitness over terseness and simplicity over convenience. My hope is to make Tempo feel like the Gleam language and to make it as difficult to write time related bugs as possible. \n\nThis package purposefully **ignores leap seconds** and **will not convert between time zones**. Try to design your application so time zones do not have to be converted between and leap seconds are trivial. More below.\n\nThis package is focused on ISO 8601 and Unix Timestamp time representations. Currently it does not support parsing or formatting to other time representations.\n\n## Installation\n```sh\ngleam add gtempo\n```\n\n[![Package Version](https://img.shields.io/hexpm/v/tempo)](https://hex.pm/packages/gtempo)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gtempo/)\n\n\n#### Time-Based Logical Branching and Logging Example\n```gleam\nimport gleam/int\nimport gleam/io\nimport tempo\nimport tempo/date\nimport tempo/datetime\nimport tempo/duration\nimport tempo/time\n\npub fn main() {\n  io.println(datetime.now_text() &lt;&gt; &quot; booting up!&quot;)\n\n  let target_time = time.literal(&quot;07:50:00&quot;)\n\n  let timer = duration.start()\n\n  case time.now_local() |&gt; time.is_later(than: target_time) {\n    True -&gt; {\n      io.println(\n        &quot;Oh no! We are late by &quot;\n        &lt;&gt; time.now_local() \n        |&gt; time.difference(from: target_time)\n        |&gt; duration.as_minutes\n        |&gt; int.to_string\n        &lt;&gt; &quot; minutes! This should take until &quot;\n        &lt;&gt; time.now_utc() \n        |&gt; time.add(duration.minutes(16)) \n        |&gt; time.to_milli_precision\n        |&gt; time.to_string\n        &lt;&gt; &quot; UTC&quot;,\n      )\n\n      run_rushed_task(for: date.current_local())\n    }\n\n    False -&gt; {\n      io.println(\n        &quot;No rush :) This should take until &quot;\n        &lt;&gt; time.now_local() \n        |&gt; time.add(duration.hours(3)) \n        |&gt; time.to_second_precision\n        |&gt; time.to_string,\n      )\n\n      run_long_task(for: date.current_local())\n    }\n  }\n\n  io.println(&quot;Phew, that only took &quot; &lt;&gt; duration.since(timer))\n}\n\n// -&gt; 2024-06-21 08:06:54.279 booting up!\n// -&gt; Oh no! We are late by 16 minutes! This should take until 12:22:54.301 UTC\n// -&gt; Phew, that only took 978 microseconds\n```\n#### Waiting Until a Specific Time Example\n```gleam\nimport gleam/erlang/process\nimport tempo/duration\nimport tempo/time\n\npub fn main() {\n  // Sleep until 8:25 if we start before then.\n  time.now_local()\n  |&gt; time.until(time.literal(&quot;08:25:00&quot;))\n  |&gt; duration.as_milliseconds\n  |&gt; process.sleep\n\n  // Now that it is 8:25, do what we need to do.\n  &quot;Hello, world!&quot;\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gtempo&gt;.\n\n## Time Zone and Leap Second Considerations\nBoth time zones and leap seconds require maintaining a manually updated database of location offsets and leap seconds. This burdens any application that uses them to keep their dependencies up to date and burdens the package by invalidating all previous versions when an update needs to be made.\n\nIf at all possible, try to design your application so that time zones do not have to be converted between. Client machines should have information about their time zone offset that can be polled and used for current time time zone conversions. This package will allow you to convert between local time and UTC time on the same date as the system date.\n\nSince this package ignores leap seconds, historical leap seconds are ignored when doing comparisons and durations. Please keep this in mind when designing your applications. Leap seconds can still be parsed from ISO 8601 strings and will be compared correctly to other times, but will not be preserved when converting to any other time representation (including changing the offset).\n\nWhen getting the system time, leap second accounting depends on the host&#39;s time implementation.\n\nIf you must, to convert between time zones with this package, use a separate time zone provider package to get the offset of the target time zone for a given date, then apply the offset to a `datetime` value (this time zone package is fictional):\n\n```gleam\nimport tempo/datetime\nimport timezone\n\npub fn main() {\n  let convertee = datetime.literal(&quot;2024-06-12T10:47:00.000Z&quot;)\n\n  convertee\n  |&gt; datetime.to_offset(timezone.offset(\n    for: &quot;America/New_York&quot;,\n    on: convertee,\n  ))\n  |&gt; datetime.to_string\n  // -&gt; &quot;2024-06-12T06:47:00.000-04:00&quot;\n}\n```\n\nTo account for leap seconds with this package, use a separate leap seconds provider package to compare dates (this leap second provider is fictional):\n\n```gleam\nimport tempo/datetime\nimport leap_second\n\npub fn main() {\n  datetime.literal(&quot;1972-06-30T23:59:59Z&quot;)\n  |&gt; leap_second.difference(from: datetime.literal(&quot;1972-07-01T00:00:00Z&quot;))\n  // -&gt; &quot;00:00:02&quot;\n}\n```\n## Development\n\n```sh\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"tempo","title":"Date","content":"pub type Date {\n  Date(year: Int, month: Month, day: Int)\n}\n A date value. It represents a specific day on the civil calendar with no\n time of day associated with it.\nDate(year: Int, month: Month, day: Int)\n\n\nSynonyms:\ntempo.Date\ntempo Date","url":"tempo.html#Date"},{"doc":"tempo","title":"DateTime","content":"pub type DateTime {\n  DateTime(naive: NaiveDateTime, offset: Offset)\n}\n A datetime value with a timezone offset associated with it. It has the \n most amount of information about a point in time, and can be compared to \n all other types in this package.\nDateTime(naive: NaiveDateTime, offset: Offset)\n\n\nSynonyms:\ntempo.DateTime\ntempo DateTime","url":"tempo.html#DateTime"},{"doc":"tempo","title":"Duration","content":"pub type Duration {\n  Duration(nanoseconds: Int)\n}\n A duration between two times. It represents a range of time values and\n can be span more than a day. It can be used to calculate the number of\n days, weeks, hours, minutes, or seconds between two times, but cannot\n accurately be used to calculate the number of years or months between.\n \n It is also used as the basis for specifying how to increase or decrease\n a datetime or time value.\nDuration(nanoseconds: Int)\n\n\nSynonyms:\ntempo.Duration\ntempo Duration","url":"tempo.html#Duration"},{"doc":"tempo","title":"Error","content":"pub type Error {\n  TimeInvalidFormat\n  TimeOutOfBounds\n  DateInvalidFormat\n  DateOutOfBounds\n  MonthInvalidFormat\n  MonthOutOfBounds\n  OffsetInvalidFormat\n  OffsetOutOfBounds\n  NaiveDateTimeInvalidFormat\n  DateTimeInvalidFormat\n}\n\nTimeInvalidFormat\n\n\nTimeOutOfBounds\n\n\nDateInvalidFormat\n\n\nDateOutOfBounds\n\n\nMonthInvalidFormat\n\n\nMonthOutOfBounds\n\n\nOffsetInvalidFormat\n\n\nOffsetOutOfBounds\n\n\nNaiveDateTimeInvalidFormat\n\n\nDateTimeInvalidFormat\n\n\nSynonyms:\ntempo.Error\ntempo Error","url":"tempo.html#Error"},{"doc":"tempo","title":"Month","content":"pub type Month {\n  Jan\n  Feb\n  Mar\n  Apr\n  May\n  Jun\n  Jul\n  Aug\n  Sep\n  Oct\n  Nov\n  Dec\n}\n A specific month on the civil calendar. \nJan\n\n\nFeb\n\n\nMar\n\n\nApr\n\n\nMay\n\n\nJun\n\n\nJul\n\n\nAug\n\n\nSep\n\n\nOct\n\n\nNov\n\n\nDec\n\n\nSynonyms:\ntempo.Month\ntempo Month","url":"tempo.html#Month"},{"doc":"tempo","title":"NaiveDateTime","content":"pub type NaiveDateTime {\n  NaiveDateTime(date: Date, time: Time)\n}\n A datetime value that does not have a timezone offset associated with it. \n It cannot be compared to datetimes with a timezone offset accurately, but\n can be compared to dates, times, and other naive datetimes.\nNaiveDateTime(date: Date, time: Time)\n\n\nSynonyms:\ntempo.NaiveDateTime\ntempo NaiveDateTime","url":"tempo.html#NaiveDateTime"},{"doc":"tempo","title":"Offset","content":"pub type Offset {\n  Offset(minutes: Int)\n}\n A timezone offset value. It represents the difference between UTC and the\n datetime value it is associated with.\nOffset(minutes: Int)\n\n\nSynonyms:\ntempo.Offset\ntempo Offset","url":"tempo.html#Offset"},{"doc":"tempo","title":"Period","content":"pub type Period {\n  Period(start: NaiveDateTime, end: NaiveDateTime)\n}\n A period between two calendar dates. It represents a range of datetimes.\n It can be used to calculate the number of days, weeks, months, or years \n between two dates. It can also be interated over and datetime values can\n be checked for inclusion in the period.\nPeriod(start: NaiveDateTime, end: NaiveDateTime)\n\n\nSynonyms:\ntempo.Period\ntempo Period","url":"tempo.html#Period"},{"doc":"tempo","title":"Time","content":"pub type Time {\n  Time(hour: Int, minute: Int, second: Int, nanosecond: Int)\n  TimeMilli(hour: Int, minute: Int, second: Int, nanosecond: Int)\n  TimeMicro(hour: Int, minute: Int, second: Int, nanosecond: Int)\n  TimeNano(hour: Int, minute: Int, second: Int, nanosecond: Int)\n}\n A time of day value. It represents a specific time on an unspecified date.\n It cannot be greater than 24 hours or less than 0 hours. It can have \n different precisions between second and nanosecond, depending on what \n your application needs.\n \n Do not use the `==` operator to check for time equality (it will not\n handle time precision correctly)! Use the compare functions instead.\nTime(hour: Int, minute: Int, second: Int, nanosecond: Int)\n\n\nTimeMilli(hour: Int, minute: Int, second: Int, nanosecond: Int)\n\n\nTimeMicro(hour: Int, minute: Int, second: Int, nanosecond: Int)\n\n\nTimeNano(hour: Int, minute: Int, second: Int, nanosecond: Int)\n\n\nSynonyms:\ntempo.Time\ntempo Time","url":"tempo.html#Time"},{"doc":"tempo","title":"UncertainConversion","content":"pub type UncertainConversion(a) {\n  Precise(a)\n  Imprecise(a)\n}\n The result of an uncertain conversion. Since this package does not track\n timezone offsets, it uses the host system&#39;s offset to convert to local\n time. If the datetime being converted to local time is of a different\n day than the current one, the offset value provided by the host may\n not be accurate (and could be accurate by up to the amount the offset \n changes throughout the year). To account for this, when converting to \n local time, a precise value is returned when the datetime being converted\n is in th current date, while an imprecise value is returned when it is\n on any other date. This allows the application logic to handle the \n two cases differently: some applications may only need to convert to \n local time on the current date or may only need generic time \n representations, while other applications may need precise conversions \n for arbitrary dates. More notes on how to plug time zones into this\n package to aviod uncertain conversions can be found in the README.\nPrecise(a)\n\n\nImprecise(a)\n\n\nSynonyms:\ntempo.UncertainConversion\ntempo UncertainConversion","url":"tempo.html#UncertainConversion"},{"doc":"tempo","title":"months","content":"pub const months: List(Month)\n An ordered list of all months in the year.\nSynonyms:\ntempo.months\ntempo months","url":"tempo.html#months"},{"doc":"tempo","title":"accept_imprecision","content":"pub fn accept_imprecision(conv: UncertainConversion(a)) -&gt; a\n Accepts either a precise or imprecise value of an uncertain conversion.\n Useful for pipelines.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T23:17:00Z&quot;)\n |&gt; datetime.to_local\n |&gt; tempo.accept_imprecision\n |&gt; datetime.to_string\n // -&gt; &quot;2024-06-21T19:17:00-04:00&quot;\n \nSynonyms:\ntempo.accept_imprecision\ntempo accept_imprecision","url":"tempo.html#accept_imprecision"},{"doc":"tempo","title":"error_on_imprecision","content":"pub fn error_on_imprecision(\n  conv: UncertainConversion(a),\n) -&gt; Result(a, Nil)\n Either returns a precise value or an error from an uncertain conversion.\n Useful for pipelines. \n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T23:17:00Z&quot;)\n |&gt; datetime.to_local\n |&gt; tempo.error_on_imprecision\n |&gt; result.try(do_important_precise_task)\n \nSynonyms:\ntempo.error_on_imprecision\ntempo error_on_imprecision","url":"tempo.html#error_on_imprecision"},{"doc":"tempo","title":"tempo","content":"","url":"tempo.html"},{"doc":"tempo/year","title":"days","content":"pub fn days(of year: Int) -&gt; Int\n Get the number of days in a year. Accounts for leap years.\n \n ## Examples\n \n \n year.days(2024)\n // -&gt; 366\n \n \n \n year.days(2025)\n // -&gt; 365\n \nSynonyms:\ntempo/year.days\ntempo/year days","url":"tempo/year.html#days"},{"doc":"tempo/year","title":"is_leap_year","content":"pub fn is_leap_year(year: Int) -&gt; Bool\n Checks if a year is a leap year.\n \n ## Examples\n \n \n year.is_leap_year(2024)\n // -&gt; True\n \n \n \n year.is_leap_year(2025)\n // -&gt; False\n \nSynonyms:\ntempo/year.is_leap_year\ntempo/year is_leap_year","url":"tempo/year.html#is_leap_year"},{"doc":"tempo/year","title":"tempo/year","content":"","url":"tempo/year.html"},{"doc":"tempo/month","title":"days","content":"pub fn days(of month: Month, in year: Int) -&gt; Int\n Returns the number of days in a month.\n \n ## Example\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.get_month\n |&gt; month.days\n // -&gt; 30\n \n \n \n date.literal(&quot;2024-12-03&quot;)\n |&gt; date.get_month\n |&gt; month.days\n // -&gt; 31\n \nSynonyms:\ntempo/month.days\ntempo/month days","url":"tempo/month.html#days"},{"doc":"tempo/month","title":"from_int","content":"pub fn from_int(month: Int) -&gt; Result(Month, Error)\n Gets a month from an integer representing the order of the month on the \n civil calendar.\n \n ## Example\n \n \n month.from_int(6)\n // -&gt; Ok(tempo.Jun)\n \n \n \n month.from_int(13)\n // -&gt; Error(Nil)\n \nSynonyms:\ntempo/month.from_int\ntempo/month from_int","url":"tempo/month.html#from_int"},{"doc":"tempo/month","title":"from_long_string","content":"pub fn from_long_string(month: String) -&gt; Result(Month, Error)\n Gets a month from a long month string.\n \n ## Example\n \n \n month.from_long_string(&quot;June&quot;)\n // -&gt; Ok(tempo.Jun)\n \n \n \n month.from_long_string(&quot;Jun&quot;)\n // -&gt; Error(Nil)\n \nSynonyms:\ntempo/month.from_long_string\ntempo/month from_long_string","url":"tempo/month.html#from_long_string"},{"doc":"tempo/month","title":"from_short_string","content":"pub fn from_short_string(month: String) -&gt; Result(Month, Error)\n Gets a month from a short month string.\n \n ## Example\n \n \n month.from_short_string(&quot;Jun&quot;)\n // -&gt; Ok(tempo.Jun)\n \n \n \n month.from_short_string(&quot;June&quot;)\n // -&gt; Error(Nil)\n \nSynonyms:\ntempo/month.from_short_string\ntempo/month from_short_string","url":"tempo/month.html#from_short_string"},{"doc":"tempo/month","title":"from_string","content":"pub fn from_string(month: String) -&gt; Result(Month, Error)\n Gets a month from a month string.\n \n ## Example\n \n \n month.from_string(&quot;Jun&quot;)\n // -&gt; Ok(tempo.Jun)\n \n \n \n month.from_string(&quot;June&quot;)\n // -&gt; Ok(tempo.Jun)\n \n \n \n month.from_string(&quot;Hello&quot;)\n // -&gt; Error(Nil)\n \nSynonyms:\ntempo/month.from_string\ntempo/month from_string","url":"tempo/month.html#from_string"},{"doc":"tempo/month","title":"next","content":"pub fn next(month: Month) -&gt; Month\n Returns the next month in the civil calendar.\n \n ## Example\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.get_month\n |&gt; month.next\n // -&gt; tempo.Jul\n \n \n \n date.literal(&quot;2024-12-03&quot;)\n |&gt; date.get_month\n |&gt; month.next\n // -&gt; tempo.Jan\n \nSynonyms:\ntempo/month.next\ntempo/month next","url":"tempo/month.html#next"},{"doc":"tempo/month","title":"prior","content":"pub fn prior(month: Month) -&gt; Month\n Returns the previous month in the civil calendar.\n \n ## Example\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.get_month\n |&gt; month.prior\n // -&gt; tempo.May\n \n \n \n date.literal(&quot;2024-01-03&quot;)\n |&gt; date.get_month\n |&gt; month.prior\n // -&gt; tempo.Dec\n \nSynonyms:\ntempo/month.prior\ntempo/month prior","url":"tempo/month.html#prior"},{"doc":"tempo/month","title":"to_int","content":"pub fn to_int(month: Month) -&gt; Int\n Returns a month&#39;s number on the civil calendar.\n \n ## Example\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.get_month\n |&gt; month.to_int\n // -&gt; 6\n \nSynonyms:\ntempo/month.to_int\ntempo/month to_int","url":"tempo/month.html#to_int"},{"doc":"tempo/month","title":"to_long_string","content":"pub fn to_long_string(month: Month) -&gt; String\n Returns a month&#39;s long name.\n \n ## Example\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.get_month\n |&gt; month.to_short_string\n // -&gt; &quot;June&quot;\n \nSynonyms:\ntempo/month.to_long_string\ntempo/month to_long_string","url":"tempo/month.html#to_long_string"},{"doc":"tempo/month","title":"to_short_string","content":"pub fn to_short_string(month: Month) -&gt; String\n Returns a month&#39;s short name.\n \n ## Example\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.get_month\n |&gt; month.to_short_string\n // -&gt; &quot;Jun&quot;\n \nSynonyms:\ntempo/month.to_short_string\ntempo/month to_short_string","url":"tempo/month.html#to_short_string"},{"doc":"tempo/month","title":"tempo/month","content":"","url":"tempo/month.html"},{"doc":"tempo/offset","title":"utc","content":"pub const utc: Offset\n The Tempo representation of the UTC offset.\nSynonyms:\ntempo/offset.utc\ntempo/offset utc","url":"tempo/offset.html#utc"},{"doc":"tempo/offset","title":"from_string","content":"pub fn from_string(offset: String) -&gt; Result(Offset, Error)\n Tries to create a new offset from a string. Accepted formats are \n `(+-)hh:mm`, `(+-)hhmm`, `(+-)hh`, and `(+-)h`.\n \n ## Example\n \n \n offset.from_string(&quot;-04&quot;)\n |&gt; result.map(offset.to_string)\n // -&gt; Ok(&quot;-04:00&quot;)\n \nSynonyms:\ntempo/offset.from_string\ntempo/offset from_string","url":"tempo/offset.html#from_string"},{"doc":"tempo/offset","title":"literal","content":"pub fn literal(offset: String) -&gt; Offset\n Creates a new offset from a string literal, but will panic if the string\n is invalid. Accepted formats are `(+-)hh:mm`, `(+-)hhmm`, `(+-)hh`, and\n `(+-)h`.\n  \n Useful for declaring offset literals that you know are valid within your \n program.\n \n ## Example\n \n \n offset.literal(&quot;-04:00&quot;)\n |&gt; offset.to_string\n // -&gt; &quot;-04:00&quot;\n \nSynonyms:\ntempo/offset.literal\ntempo/offset literal","url":"tempo/offset.html#literal"},{"doc":"tempo/offset","title":"new","content":"pub fn new(offset_minutes minutes: Int) -&gt; Result(Offset, Error)\n Creates a new offset from a number of minutes.\n \n ## Example\n \n \n offset.new(-65)\n |&gt; result.map(offset.to_string)\n // -&gt; Ok(&quot;-01:05&quot;)\n \nSynonyms:\ntempo/offset.new\ntempo/offset new","url":"tempo/offset.html#new"},{"doc":"tempo/offset","title":"to_string","content":"pub fn to_string(offset: Offset) -&gt; String\n Converts an offset to a string representation.\n \n Will not return &quot;Z&quot; for a zero offset because it is probably not what\n the user wants without the context of a full datetime. Datetime modules\n building on this should cover formatting for Z themselves.\n \n ## Example\n \n \n offset.literal(&quot;-00&quot;)\n |&gt; offset.to_string\n // -&gt; &quot;-00:00&quot;\n \nSynonyms:\ntempo/offset.to_string\ntempo/offset to_string","url":"tempo/offset.html#to_string"},{"doc":"tempo/offset","title":"tempo/offset","content":"","url":"tempo/offset.html"},{"doc":"tempo/date","title":"DayOfWeek","content":"pub type DayOfWeek {\n  Sun\n  Mon\n  Tue\n  Wed\n  Thu\n  Fri\n  Sat\n}\n\nSun\n\n\nMon\n\n\nTue\n\n\nWed\n\n\nThu\n\n\nFri\n\n\nSat\n\n\nSynonyms:\ntempo/date.DayOfWeek\ntempo/date DayOfWeek","url":"tempo/date.html#DayOfWeek"},{"doc":"tempo/date","title":"add","content":"pub fn add(date: Date, days days: Int) -&gt; Date\n Adds a number of days to a date.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.add(days: 1)\n // -&gt; date.literal(&quot;2024-06-13&quot;)\n \n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.add(days: 12)\n // -&gt; date.literal(&quot;2024-06-24&quot;)\n \nSynonyms:\ntempo/date.add\ntempo/date add","url":"tempo/date.html#add"},{"doc":"tempo/date","title":"as_period","content":"pub fn as_period(start: Date, end: Date) -&gt; Period\n Creates a period between two UTC dates at 00:00:00 each.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.difference(from: date.literal(&quot;2024-06-23&quot;))\n |&gt; period.as_days\n // -&gt; 11\n \n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.difference(from: date.literal(&quot;2024-06-03&quot;))\n |&gt; period.as_days\n // -&gt; 9\n \nSynonyms:\ntempo/date.as_period\ntempo/date as_period","url":"tempo/date.html#as_period"},{"doc":"tempo/date","title":"compare","content":"pub fn compare(a: Date, to b: Date) -&gt; Order\n Compares two dates.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.compare(to: date.literal(&quot;2024-06-12&quot;))\n // -&gt; order.Eq\n \n \n \n date.literal(&quot;2024-05-12&quot;)\n |&gt; date.compare(to: date.literal(&quot;2024-06-13&quot;))\n // -&gt; order.Lt\n \n \n \n date.literal(&quot;2034-06-12&quot;)\n |&gt; date.compare(to: date.literal(&quot;2024-06-11&quot;))\n // -&gt; order.Gt\n \nSynonyms:\ntempo/date.compare\ntempo/date compare","url":"tempo/date.html#compare"},{"doc":"tempo/date","title":"current_local","content":"pub fn current_local() -&gt; Date\n Gets the current local date of the host.\n \n ## Examples\n \n \n date.current_local()\n |&gt; date.to_string\n // -&gt; &quot;2024-06-13&quot;\n \nSynonyms:\ntempo/date.current_local\ntempo/date current_local","url":"tempo/date.html#current_local"},{"doc":"tempo/date","title":"current_utc","content":"pub fn current_utc() -&gt; Date\n Gets the current UTC date of the host.\n \n ## Examples\n \n \n date.current_utc()\n |&gt; date.to_string\n // -&gt; &quot;2024-06-14&quot;\n \nSynonyms:\ntempo/date.current_utc\ntempo/date current_utc","url":"tempo/date.html#current_utc"},{"doc":"tempo/date","title":"difference","content":"pub fn difference(of a: Date, from b: Date) -&gt; Period\n Gets the difference between two dates as a period between the two UTC dates\n at 00:00:00 each.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.difference(from: date.literal(&quot;2024-06-23&quot;))\n |&gt; period.as_days\n // -&gt; 11\n \n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.difference(from: date.literal(&quot;2024-06-03&quot;))\n |&gt; period.as_days\n // -&gt; 9\n \nSynonyms:\ntempo/date.difference\ntempo/date difference","url":"tempo/date.html#difference"},{"doc":"tempo/date","title":"from_dynamic_string","content":"pub fn from_dynamic_string(\n  dynamic_string: Dynamic,\n) -&gt; Result(Date, List(DecodeError))\n Checks if a dynamic value is a valid date string, and returns the\n date if it is.\n \n ## Examples\n \n \n dynamic.from(&quot;2024-06-21&quot;)\n |&gt; date.from_dynamic_string\n // -&gt; Ok(date.literal(&quot;2024-06-21&quot;))\n \n \n \n dynamic.from(&quot;153&quot;)\n |&gt; datetime.from_dynamic_string\n // -&gt; Error([\n //   dynamic.DecodeError(\n //     expected: &quot;tempo.Date&quot;,\n //     found: &quot;Invalid format: 153&quot;,\n //     path: [],\n //   ),\n // ])\n \nSynonyms:\ntempo/date.from_dynamic_string\ntempo/date from_dynamic_string","url":"tempo/date.html#from_dynamic_string"},{"doc":"tempo/date","title":"from_string","content":"pub fn from_string(date: String) -&gt; Result(Date, Error)\n Parses a date string in the format `YYYY-MM-DD`, `YYYY-M-D`, `YYYY/MM/DD`, \n `YYYY/M/D`, `YYYY.MM.DD`, `YYYY.M.D`, `YYYY_MM_DD`, `YYYY_M_D`, `YYYY MM DD`,\n `YYYY M D`, or `YYYYMMDD`.\n \n ## Examples\n \n \n date.from_string(&quot;2024-06-13&quot;)\n // -&gt; Ok(date.literal(&quot;2024-06-13&quot;))\n \n \n \n date.from_string(&quot;20240613&quot;)\n // -&gt; Ok(date.literal(&quot;2024-06-13&quot;))\n \n \n \n date.from_string(&quot;2409&quot;)\n // -&gt; Error(tempo.DateInvalidFormat)\n \nSynonyms:\ntempo/date.from_string\ntempo/date from_string","url":"tempo/date.html#from_string"},{"doc":"tempo/date","title":"from_tuple","content":"pub fn from_tuple(date: #(Int, Int, Int)) -&gt; Result(Date, Error)\n Returns a date value from a tuple of ints if the values represent the \n years, month, and day of a valid date. The year must be greater than 1000.\n \n Years less than 1000 are technically valid years, but are not common \n and usually indicate that either a non-year value was passed as the year\n or a two digit year was passed (which are too abiguous to be confidently\n accepted).\n \n ## Examples\n \n \n date.from_tuple(#(2024, 6, 13))\n // -&gt; Ok(date.literal(&quot;2024-06-13&quot;))\n \n \n \n date.from_tuple(#(98, 6, 13))\n // -&gt; Error(tempo.DateOutOfBounds)\n \nSynonyms:\ntempo/date.from_tuple\ntempo/date from_tuple","url":"tempo/date.html#from_tuple"},{"doc":"tempo/date","title":"get_day","content":"pub fn get_day(date: Date) -&gt; Int\n Gets the day value of a date.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.get_day\n // -&gt; 13\n \nSynonyms:\ntempo/date.get_day\ntempo/date get_day","url":"tempo/date.html#get_day"},{"doc":"tempo/date","title":"get_month","content":"pub fn get_month(date: Date) -&gt; Month\n Gets the month value of a date.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.get_month\n // -&gt; tempo.Jun\n \nSynonyms:\ntempo/date.get_month\ntempo/date get_month","url":"tempo/date.html#get_month"},{"doc":"tempo/date","title":"get_year","content":"pub fn get_year(date: Date) -&gt; Int\n Gets the year value of a date.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.get_year\n // -&gt; 2024\n \nSynonyms:\ntempo/date.get_year\ntempo/date get_year","url":"tempo/date.html#get_year"},{"doc":"tempo/date","title":"is_earlier","content":"pub fn is_earlier(a: Date, than b: Date) -&gt; Bool\n Checks of the first date is earlier than the second date.\n\n ## Examples\n\n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.is_earlier(than: date.literal(&quot;2024-06-13&quot;))\n // -&gt; True\n \n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.is_earlier(than: date.literal(&quot;2024-06-12&quot;))\n // -&gt; False\n \nSynonyms:\ntempo/date.is_earlier\ntempo/date is_earlier","url":"tempo/date.html#is_earlier"},{"doc":"tempo/date","title":"is_earlier_or_equal","content":"pub fn is_earlier_or_equal(a: Date, to b: Date) -&gt; Bool\n Checks if the first date is earlier than or equal to the second date.\n \n ## Examples\n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.is_earlier_or_equal(to: date.literal(&quot;2024-06-12&quot;))\n // -&gt; True\n \n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.is_earlier_or_equal(to: date.literal(&quot;2024-06-11&quot;))\n // -&gt; False\n \nSynonyms:\ntempo/date.is_earlier_or_equal\ntempo/date is_earlier_or_equal","url":"tempo/date.html#is_earlier_or_equal"},{"doc":"tempo/date","title":"is_equal","content":"pub fn is_equal(a: Date, to b: Date) -&gt; Bool\n Checks if two dates are equal.\n\n ## Example\n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.is_equal(to: date.literal(&quot;2024-06-12&quot;))\n // -&gt; True\n \nSynonyms:\ntempo/date.is_equal\ntempo/date is_equal","url":"tempo/date.html#is_equal"},{"doc":"tempo/date","title":"is_later","content":"pub fn is_later(a: Date, than b: Date) -&gt; Bool\n Checks if the first date is later than the second date.\n\n ## Examples\n\n \n date.literal(&quot;2024-06-14&quot;)\n |&gt; date.is_later(than: date.literal(&quot;2024-06-13&quot;))\n // -&gt; True\n \n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.is_later(than: date.literal(&quot;2024-06-12&quot;))\n // -&gt; False\n \nSynonyms:\ntempo/date.is_later\ntempo/date is_later","url":"tempo/date.html#is_later"},{"doc":"tempo/date","title":"is_later_or_equal","content":"pub fn is_later_or_equal(a: Date, to b: Date) -&gt; Bool\n Checks if the first date is later than or equal to the second date.\n \n ## Examples\n\n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.is_later_or_equal(to: date.literal(&quot;2024-06-12&quot;))\n // -&gt; True\n \n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.is_later_or_equal(to: date.literal(&quot;2024-06-13&quot;))\n // -&gt; False\n \nSynonyms:\ntempo/date.is_later_or_equal\ntempo/date is_later_or_equal","url":"tempo/date.html#is_later_or_equal"},{"doc":"tempo/date","title":"is_weekend","content":"pub fn is_weekend(date: Date) -&gt; Bool\n Checks if a date falls in a weekend.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-22&quot;)\n |&gt; date.is_weekend\n // -&gt; True\n \nSynonyms:\ntempo/date.is_weekend\ntempo/date is_weekend","url":"tempo/date.html#is_weekend"},{"doc":"tempo/date","title":"literal","content":"pub fn literal(date: String) -&gt; Date\n Creates a new date value from a string literal, but will panic if\n the string is invalid. Accepted formats are `YYYY-MM-DD`, `YYYY-M-D`,\n `YYYY/MM/DD`, `YYYY/M/D`, `YYYY.MM.DD`, `YYYY.M.D`, `YYYY_MM_DD`,\n `YYYY_M_D`, `YYYY MM DD`, `YYYY M D`, or `YYYYMMDD`.\n \n Useful for declaring date literals that you know are valid within your  \n program.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.to_string\n // -&gt; &quot;2024-06-13&quot;\n \n \n \n date.literal(&quot;20240613&quot;)\n |&gt; date.to_string\n // -&gt; &quot;2024-06-13&quot;\n \n \n \n date.literal(&quot;2409&quot;)\n // -&gt; panic\n \nSynonyms:\ntempo/date.literal\ntempo/date literal","url":"tempo/date.html#literal"},{"doc":"tempo/date","title":"new","content":"pub fn new(\n  year year: Int,\n  month month: Int,\n  day day: Int,\n) -&gt; Result(Date, Error)\n Creates a new date and validates it.\n \n ## Examples\n \n \n date.new(2024, 6, 13)\n // -&gt; Ok(date.literal(&quot;2024-06-13&quot;))\n \n \n \n date.new(2024, 6, 31)\n // -&gt; Error(tempo.DateOutOfBounds)\n \nSynonyms:\ntempo/date.new\ntempo/date new","url":"tempo/date.html#new"},{"doc":"tempo/date","title":"subtract","content":"pub fn subtract(date: Date, days days: Int) -&gt; Date\n Subtracts a number of days from a date.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.subtract(days: 1)\n // -&gt; date.literal(&quot;2024-06-11&quot;)\n \n \n \n date.literal(&quot;2024-06-12&quot;)\n |&gt; date.subtract(days: 12)\n // -&gt; date.literal(&quot;2024-05-31&quot;)\n \nSynonyms:\ntempo/date.subtract\ntempo/date subtract","url":"tempo/date.html#subtract"},{"doc":"tempo/date","title":"to_string","content":"pub fn to_string(date: Date) -&gt; String\n Returns a string representation of a date value in the format `YYYY-MM-DD`.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-13&quot;)\n |&gt; date.to_string\n // -&gt; &quot;2024-06-13&quot;\n \nSynonyms:\ntempo/date.to_string\ntempo/date to_string","url":"tempo/date.html#to_string"},{"doc":"tempo/date","title":"to_tuple","content":"pub fn to_tuple(date: Date) -&gt; #(Int, Int, Int)\n Returns a tuple of ints from a date value that represent the year, month,\n and day of the date.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-14&quot;)\n |&gt; date.to_tuple\n // -&gt; #(2024, 6, 14)\n \nSynonyms:\ntempo/date.to_tuple\ntempo/date to_tuple","url":"tempo/date.html#to_tuple"},{"doc":"tempo/date","title":"to_weekday","content":"pub fn to_weekday(date: Date) -&gt; DayOfWeek\n Returns the day of week a date falls on.\n Will be incorrect for dates before 1752 and dates after 2300.\n \n ## Examples\n \n \n date.literal(&quot;2024-06-20&quot;)\n |&gt; date.to_weekday\n // -&gt; Thur\n \nSynonyms:\ntempo/date.to_weekday\ntempo/date to_weekday","url":"tempo/date.html#to_weekday"},{"doc":"tempo/date","title":"tempo/date","content":"","url":"tempo/date.html"},{"doc":"tempo/duration","title":"MonotonicClock","content":"pub opaque type MonotonicClock\n\n\nSynonyms:\ntempo/duration.MonotonicClock\ntempo/duration MonotonicClock","url":"tempo/duration.html#MonotonicClock"},{"doc":"tempo/duration","title":"Unit","content":"pub type Unit {\n  YearImprecise\n  Week\n  Day\n  Hour\n  Minute\n  Second\n  Millisecond\n  Microsecond\n  Nanosecond\n}\n\nYearImprecise\n\n\nWeek\n\n\nDay\n\n\nHour\n\n\nMinute\n\n\nSecond\n\n\nMillisecond\n\n\nMicrosecond\n\n\nNanosecond\n\n\nSynonyms:\ntempo/duration.Unit\ntempo/duration Unit","url":"tempo/duration.html#Unit"},{"doc":"tempo/duration","title":"absolute","content":"pub fn absolute(duration: Duration) -&gt; Duration\n Returns the absolute value of a duration.\n \n ## Example\n \n \n duration.days(1)\n |&gt; duration.decrease(by: duration.days(6))\n |&gt; duration.abosulte\n |&gt; duration.format_as(duration.Day, decimals: 0)\n // -&gt; &quot;5 days&quot;\n \nSynonyms:\ntempo/duration.absolute\ntempo/duration absolute","url":"tempo/duration.html#absolute"},{"doc":"tempo/duration","title":"as_days","content":"pub fn as_days(duration: Duration) -&gt; Int\n Converts a duration to the equivalent number of whole days.\nSynonyms:\ntempo/duration.as_days\ntempo/duration as_days","url":"tempo/duration.html#as_days"},{"doc":"tempo/duration","title":"as_days_fractional","content":"pub fn as_days_fractional(duration: Duration) -&gt; Float\n Converts a duration to the equivalent number of fractional days.\nSynonyms:\ntempo/duration.as_days_fractional\ntempo/duration as_days_fractional","url":"tempo/duration.html#as_days_fractional"},{"doc":"tempo/duration","title":"as_hours","content":"pub fn as_hours(duration: Duration) -&gt; Int\n Converts a duration to the equivalent number of whole hours.\nSynonyms:\ntempo/duration.as_hours\ntempo/duration as_hours","url":"tempo/duration.html#as_hours"},{"doc":"tempo/duration","title":"as_hours_fractional","content":"pub fn as_hours_fractional(duration: Duration) -&gt; Float\n Converts a duration to the equivalent number of fractional hours.\nSynonyms:\ntempo/duration.as_hours_fractional\ntempo/duration as_hours_fractional","url":"tempo/duration.html#as_hours_fractional"},{"doc":"tempo/duration","title":"as_microseconds","content":"pub fn as_microseconds(duration: Duration) -&gt; Int\n Converts a duration to the equivalent number of whole microseconds.\nSynonyms:\ntempo/duration.as_microseconds\ntempo/duration as_microseconds","url":"tempo/duration.html#as_microseconds"},{"doc":"tempo/duration","title":"as_microseconds_fractional","content":"pub fn as_microseconds_fractional(duration: Duration) -&gt; Float\n Converts a duration to the equivalent number of fractional microseconds.\nSynonyms:\ntempo/duration.as_microseconds_fractional\ntempo/duration as_microseconds_fractional","url":"tempo/duration.html#as_microseconds_fractional"},{"doc":"tempo/duration","title":"as_milliseconds","content":"pub fn as_milliseconds(duration: Duration) -&gt; Int\n Converts a duration to the equivalent number of whole milliseconds.\nSynonyms:\ntempo/duration.as_milliseconds\ntempo/duration as_milliseconds","url":"tempo/duration.html#as_milliseconds"},{"doc":"tempo/duration","title":"as_milliseconds_fractional","content":"pub fn as_milliseconds_fractional(duration: Duration) -&gt; Float\n Converts a duration to the equivalent number of fractional milliseconds.\nSynonyms:\ntempo/duration.as_milliseconds_fractional\ntempo/duration as_milliseconds_fractional","url":"tempo/duration.html#as_milliseconds_fractional"},{"doc":"tempo/duration","title":"as_minutes","content":"pub fn as_minutes(duration: Duration) -&gt; Int\n Converts a duration to the equivalent number of whole minutes.\nSynonyms:\ntempo/duration.as_minutes\ntempo/duration as_minutes","url":"tempo/duration.html#as_minutes"},{"doc":"tempo/duration","title":"as_minutes_fractional","content":"pub fn as_minutes_fractional(duration: Duration) -&gt; Float\n Converts a duration to the equivalent number of fractional minutes.\nSynonyms:\ntempo/duration.as_minutes_fractional\ntempo/duration as_minutes_fractional","url":"tempo/duration.html#as_minutes_fractional"},{"doc":"tempo/duration","title":"as_nanoseconds","content":"pub fn as_nanoseconds(duration: Duration) -&gt; Int\n Converts a duration to the equivalent number of whole nanoseconds.\nSynonyms:\ntempo/duration.as_nanoseconds\ntempo/duration as_nanoseconds","url":"tempo/duration.html#as_nanoseconds"},{"doc":"tempo/duration","title":"as_nanoseconds_fractional","content":"pub fn as_nanoseconds_fractional(duration: Duration) -&gt; Float\n Converts a duration to a floating point representation of nanoseconds.\n Nanoseconds are the smallest unit of time that are used in this package.\nSynonyms:\ntempo/duration.as_nanoseconds_fractional\ntempo/duration as_nanoseconds_fractional","url":"tempo/duration.html#as_nanoseconds_fractional"},{"doc":"tempo/duration","title":"as_seconds","content":"pub fn as_seconds(duration: Duration) -&gt; Int\n Converts a duration to the equivalent number of whole seconds.\nSynonyms:\ntempo/duration.as_seconds\ntempo/duration as_seconds","url":"tempo/duration.html#as_seconds"},{"doc":"tempo/duration","title":"as_seconds_fractional","content":"pub fn as_seconds_fractional(duration: Duration) -&gt; Float\n Converts a duration to the equivalent number of fractional seconds.\nSynonyms:\ntempo/duration.as_seconds_fractional\ntempo/duration as_seconds_fractional","url":"tempo/duration.html#as_seconds_fractional"},{"doc":"tempo/duration","title":"as_unit","content":"pub fn as_unit(duration: Duration, unit: Unit) -&gt; Int\n Converts a duration to the specified whole units.\n \n ## Example\n \n \n duration.minutes(1)\n |&gt; duration.as_unit(duration.Second)\n // -&gt; 60\n \nSynonyms:\ntempo/duration.as_unit\ntempo/duration as_unit","url":"tempo/duration.html#as_unit"},{"doc":"tempo/duration","title":"as_unit_fractional","content":"pub fn as_unit_fractional(\n  duration: Duration,\n  unit: Unit,\n) -&gt; Float\n Converts a duration to the specified fractional units.\n \n ## Example\n \n \n duration.days(8)\n |&gt; duration.as_unit_fractional(duration.Week)\n // -&gt; 1.142857143\n \nSynonyms:\ntempo/duration.as_unit_fractional\ntempo/duration as_unit_fractional","url":"tempo/duration.html#as_unit_fractional"},{"doc":"tempo/duration","title":"as_weeks","content":"pub fn as_weeks(duration: Duration) -&gt; Int\n Converts a duration to the equivalent number of whole weeks.\nSynonyms:\ntempo/duration.as_weeks\ntempo/duration as_weeks","url":"tempo/duration.html#as_weeks"},{"doc":"tempo/duration","title":"as_weeks_fractional","content":"pub fn as_weeks_fractional(duration: Duration) -&gt; Float\n Converts a duration to the equivalent number of fractional weeks.\nSynonyms:\ntempo/duration.as_weeks_fractional\ntempo/duration as_weeks_fractional","url":"tempo/duration.html#as_weeks_fractional"},{"doc":"tempo/duration","title":"as_years_fractional_imprecise","content":"pub fn as_years_fractional_imprecise(duration: Duration) -&gt; Float\n Converts a duration to the equivalent number of fractional years, \n assuming a year is 365 days.\n \n ## Example\n \n \n duration.days(375)\n |&gt; duration.as_years_fractional_imprecise\n // -&gt; 1.02739726\n \nSynonyms:\ntempo/duration.as_years_fractional_imprecise\ntempo/duration as_years_fractional_imprecise","url":"tempo/duration.html#as_years_fractional_imprecise"},{"doc":"tempo/duration","title":"as_years_imprecise","content":"pub fn as_years_imprecise(duration: Duration) -&gt; Int\n Converts a duration to the equivalent number of whole years, assuming \n a year is 365 days.\n \n ## Example\n \n \n duration.days(375)\n |&gt; duration.as_years_imprecise\n // -&gt; 1\n \nSynonyms:\ntempo/duration.as_years_imprecise\ntempo/duration as_years_imprecise","url":"tempo/duration.html#as_years_imprecise"},{"doc":"tempo/duration","title":"compare","content":"pub fn compare(a: Duration, to b: Duration) -&gt; Order\n Compares two durations.\n \n ## Example\n \n \n duration.days(1)\n |&gt; duration.compare(to: duration.days(1))\n // -&gt; order.Eq\n \n \n \n duration.days(1)\n |&gt; duration.compare(to: duration.days(2))\n // -&gt; order.Lt\n \nSynonyms:\ntempo/duration.compare\ntempo/duration compare","url":"tempo/duration.html#compare"},{"doc":"tempo/duration","title":"days","content":"pub fn days(days: Int) -&gt; Duration\n Creates a new duration value of the specified number of whole days.\n \n ## Example\n \n \n duration.days(3)\n |&gt; duration.format_as(duration.Hour, decimals: 0)\n // -&gt; &quot;36 hours&quot;\n \nSynonyms:\ntempo/duration.days\ntempo/duration days","url":"tempo/duration.html#days"},{"doc":"tempo/duration","title":"decrease","content":"pub fn decrease(a: Duration, by b: Duration) -&gt; Duration\n Decreases a duration by the specified duration.\n \n ## Example\n \n \n duration.days(1)\n |&gt; duration.decrease(by: duration.days(6))\n |&gt; duration.format_as(duration.Day, decimals: 0)\n // -&gt; &quot;-5 days&quot;\n \n \n \n duration.days(1)\n |&gt; duration.decrease(by: duration.days(6))\n |&gt; duration.abosulte\n |&gt; duration.format_as(duration.Day, decimals: 0)\n // -&gt; &quot;5 days&quot;\n \nSynonyms:\ntempo/duration.decrease\ntempo/duration decrease","url":"tempo/duration.html#decrease"},{"doc":"tempo/duration","title":"format","content":"pub fn format(duration: Duration) -&gt; String\n Formats the duration as a string, inferring the units to use.\n \n ## Example\n \n \n duration.nanoseconds(172_980_000_000_000)\n |&gt; duration.format\n // -&gt; &quot;2 days, 0 hours, and 3 minutes&quot;\n \n \n \n duration.seconds(691_332_000_000)\n |&gt; duration.format\n // -&gt; &quot;1 week, 1 day, 0 hours, and 2 minutes&quot;\n \nSynonyms:\ntempo/duration.format\ntempo/duration format","url":"tempo/duration.html#format"},{"doc":"tempo/duration","title":"format_as","content":"pub fn format_as(\n  duration: Duration,\n  unit unit: Unit,\n  decimals decimals: Int,\n) -&gt; String\n Formats the duration as the specified unit with the specified number \n of decimals.\n \n ## Example\n \n \n duration.minutes(1)\n |&gt; duration.format_as(duration.Second, decimals: 3)\n // -&gt; &quot;60.000 minutes&quot;\n \nSynonyms:\ntempo/duration.format_as\ntempo/duration format_as","url":"tempo/duration.html#format_as"},{"doc":"tempo/duration","title":"format_as_many","content":"pub fn format_as_many(\n  duration: Duration,\n  units units: List(Unit),\n  decimals decimals: Int,\n) -&gt; String\n Formats the duration as the specified units, with the last unit having\n the specified number of decimals.\n \n ## Example\n \n \n duration.milliseconds(100_303)\n |&gt; duration.format_as_many(\n   [duration.Minute, duration.Second],\n   decimals: 2,\n )\n // -&gt; &quot;1 minute and 40.30 seconds&quot;\n \nSynonyms:\ntempo/duration.format_as_many\ntempo/duration format_as_many","url":"tempo/duration.html#format_as_many"},{"doc":"tempo/duration","title":"hours","content":"pub fn hours(hours: Int) -&gt; Duration\n Creates a new duration value of the specified number of whole hours.\n \n ## Example\n \n \n duration.hours(13)\n |&gt; duration.format\n // -&gt; &quot;13 hours, 0 minutes, 0.0 seconds&quot;\n \nSynonyms:\ntempo/duration.hours\ntempo/duration hours","url":"tempo/duration.html#hours"},{"doc":"tempo/duration","title":"increase","content":"pub fn increase(a: Duration, by b: Duration) -&gt; Duration\n Increases a duration by the specified duration.\n \n ## Example\n \n \n duration.days(1)\n |&gt; duration.increase(by: duration.days(6))\n |&gt; duration.format_as(duration.Day, decimals: 0)\n // -&gt; &quot;7 days&quot;\n \nSynonyms:\ntempo/duration.increase\ntempo/duration increase","url":"tempo/duration.html#increase"},{"doc":"tempo/duration","title":"inverse","content":"pub fn inverse(duration: Duration) -&gt; Duration\n Returns the inverse of a duration.\n \n ## Example\n \n \n duration.days(1)\n |&gt; duration.inverse\n |&gt; duration.format_as(duration.Day, decimals: 0)\n // -&gt; &quot;-1 days&quot;\n \n \nSynonyms:\ntempo/duration.inverse\ntempo/duration inverse","url":"tempo/duration.html#inverse"},{"doc":"tempo/duration","title":"is_equal","content":"pub fn is_equal(a: Duration, to b: Duration) -&gt; Bool\n Checks if a duration is equal to another duration.\n \n ## Example\n \n \n duration.weeks(1)\n |&gt; duration.is_equal(to: duration.days(7))\n // -&gt; True\n \n \n \n duration.days(1)\n |&gt; duration.is_equal(to: duration.days(2))\n // -&gt; False\n \nSynonyms:\ntempo/duration.is_equal\ntempo/duration is_equal","url":"tempo/duration.html#is_equal"},{"doc":"tempo/duration","title":"is_greater","content":"pub fn is_greater(a: Duration, than b: Duration) -&gt; Bool\n Checks if a duration is greater than another duration.\n\n ## Example\n\n \n duration.days(1)\n |&gt; duration.is_greater(than: duration.days(2))\n // -&gt; False\n \n\n \n duration.weeks(1)\n |&gt; duration.is_greater(than: duration.days(1))\n // -&gt; True\n  \nSynonyms:\ntempo/duration.is_greater\ntempo/duration is_greater","url":"tempo/duration.html#is_greater"},{"doc":"tempo/duration","title":"is_greater_or_equal","content":"pub fn is_greater_or_equal(a: Duration, to b: Duration) -&gt; Bool\n Checks if a duration is greater than or equal to another duration.\n \n ## Example\n \n \n duration.days(1)\n |&gt; duration.is_greater_or_equal(to: duration.days(2))\n // -&gt; False\n \n \n \n duration.seconds(60)\n |&gt; duration.is_greater_or_equal(to: duration.minutes(1))\n // -&gt; True\n \nSynonyms:\ntempo/duration.is_greater_or_equal\ntempo/duration is_greater_or_equal","url":"tempo/duration.html#is_greater_or_equal"},{"doc":"tempo/duration","title":"is_less","content":"pub fn is_less(a: Duration, than b: Duration) -&gt; Bool\n Checks if a duration is less than another duration.\n\n ## Example\n\n \n duration.days(1)\n |&gt; duration.is_less(than: duration.hours(25))\n // -&gt; True\n \n\n \n duration.days(1)\n |&gt; duration.is_less(than: duration.days(1))\n // -&gt; False\n \nSynonyms:\ntempo/duration.is_less\ntempo/duration is_less","url":"tempo/duration.html#is_less"},{"doc":"tempo/duration","title":"is_less_or_equal","content":"pub fn is_less_or_equal(a: Duration, to b: Duration) -&gt; Bool\n Checks if a duration is less than or equal to another duration.\n \n ## Example\n \n \n duration.days(1)\n |&gt; duration.is_less_or_equal(to: duration.days(2))\n // -&gt; True\n \n \n \n duration.days(1)\n |&gt; duration.is_less_or_equal(to: duration.days(1))\n // -&gt; True\n \nSynonyms:\ntempo/duration.is_less_or_equal\ntempo/duration is_less_or_equal","url":"tempo/duration.html#is_less_or_equal"},{"doc":"tempo/duration","title":"is_negative","content":"pub fn is_negative(duration: Duration) -&gt; Bool\n Checks if a duration is negative.\n \n ## Example\n \n \n duration.days(1)\n |&gt; duration.is_negative\n // -&gt; False\n \n \n \n case \n   time.literal(&quot;13:42:05&quot;)\n   |&gt; time.difference(from: time.literal(&quot;13:42:10&quot;))\n   |&gt; duration.is_negative\n {\n   True -&gt; &quot;we are ahead of time!&quot;\n   False -&gt; &quot;We are either on time or late!&quot;\n }\n \nSynonyms:\ntempo/duration.is_negative\ntempo/duration is_negative","url":"tempo/duration.html#is_negative"},{"doc":"tempo/duration","title":"microseconds","content":"pub fn microseconds(microseconds: Int) -&gt; Duration\n Creates a new duration value of the specified number of whole microseconds.\n \n ## Example\n \n \n duration.milliseconds(1)\n |&gt; duration.increase(by: duration.microseconds(13))\n |&gt; duration.format_as(duration.Microsecond, decimals: 0)\n // -&gt; &quot;113 microseconds&quot;\n \nSynonyms:\ntempo/duration.microseconds\ntempo/duration microseconds","url":"tempo/duration.html#microseconds"},{"doc":"tempo/duration","title":"milliseconds","content":"pub fn milliseconds(milliseconds: Int) -&gt; Duration\n Creates a new duration value of the specified number of whole milliseconds.\n \n ## Example\n \n \n duration.seconds(1)\n |&gt; duration.increase(by: duration.milliseconds(13))\n |&gt; duration.format_as(duration.Millisecond, decimals: 0)\n // -&gt; &quot;113 milliseconds&quot;\n \nSynonyms:\ntempo/duration.milliseconds\ntempo/duration milliseconds","url":"tempo/duration.html#milliseconds"},{"doc":"tempo/duration","title":"minutes","content":"pub fn minutes(minutes: Int) -&gt; Duration\n Creates a new duration value of the specified number of whole minutes.\n \n ## Example\n \n \n duration.minutes(13)\n |&gt; duration.format\n // -&gt; &quot;13 minutes and 0.0 seconds&quot;\n \nSynonyms:\ntempo/duration.minutes\ntempo/duration minutes","url":"tempo/duration.html#minutes"},{"doc":"tempo/duration","title":"nanoseconds","content":"pub fn nanoseconds(nanoseconds: Int) -&gt; Duration\n Creates a new duration value of the specified number of whole nanoseconds.\n \n ## Example\n \n \n duration.microseconds(1)\n |&gt; duration.increase(by: duration.nanoseconds(13))\n |&gt; duration.format_as(duration.Nanosecond, decimals: 0)\n // -&gt; &quot;113 nanoseconds&quot;\n \nSynonyms:\ntempo/duration.nanoseconds\ntempo/duration nanoseconds","url":"tempo/duration.html#nanoseconds"},{"doc":"tempo/duration","title":"new","content":"pub fn new(duration: Int, unit: Unit) -&gt; Duration\n Creates a new duration from the value and unit provided.\n \n ## Example\n \n \n duration.new(100, duration.Millisecond)\n |&gt; duration.as_seconds_fractional\n // -&gt; 0.0000001\n \nSynonyms:\ntempo/duration.new\ntempo/duration new","url":"tempo/duration.html#new"},{"doc":"tempo/duration","title":"seconds","content":"pub fn seconds(seconds: Int) -&gt; Duration\n Creates a new duration value of the specified number of whole seconds.\n \n ## Example\n \n \n duration.minutes(1)\n |&gt; duration.increase(by: duration.seconds(13))\n |&gt; duration.format_as(duration.Second, decimals: 0)\n // -&gt; &quot;73 seconds&quot;\n \nSynonyms:\ntempo/duration.seconds\ntempo/duration seconds","url":"tempo/duration.html#seconds"},{"doc":"tempo/duration","title":"since","content":"pub fn since(start: MonotonicClock) -&gt; String\n Returns the formatted duration between the monotonic clock start and \n the current time.\n \n ## Example\n \n \n duration.start()\n |&gt; fn(timer) { \n   &quot;This operation took &quot;\n   &lt;&gt; duration.since(timer)\n   &lt;&gt; &quot;!&quot; \n }\n // -&gt; &quot;This operation took 263 nanoseconds!&quot;\n \nSynonyms:\ntempo/duration.since\ntempo/duration since","url":"tempo/duration.html#since"},{"doc":"tempo/duration","title":"start","content":"pub fn start() -&gt; MonotonicClock\n Starts a new monotonic clock.\n \n ## Example\n \n \n duration.start()\n |&gt; function.tap(fn(_) { long_function() })\n |&gt; duration.stop\n // -&gt; duration.mintues(15)\n \nSynonyms:\ntempo/duration.start\ntempo/duration start","url":"tempo/duration.html#start"},{"doc":"tempo/duration","title":"stop","content":"pub fn stop(start: MonotonicClock) -&gt; Duration\n Returns the duration between the monotonic clock start and the current time.\n \n ## Example\n \n \n duration.start()\n |&gt; function.tap(fn(_) { long_function() })\n |&gt; duration.stop\n // -&gt; duration.mintues(15)\n \nSynonyms:\ntempo/duration.stop\ntempo/duration stop","url":"tempo/duration.html#stop"},{"doc":"tempo/duration","title":"weeks","content":"pub fn weeks(weeks: Int) -&gt; Duration\n Creates a new duration value of the specified number of whole weeks.\n \n ## Example\n \n \n duration.weeks(3)\n |&gt; duration.format\n // -&gt; &quot;3 weeks&quot;\n \nSynonyms:\ntempo/duration.weeks\ntempo/duration weeks","url":"tempo/duration.html#weeks"},{"doc":"tempo/duration","title":"years_imprecise","content":"pub fn years_imprecise(years: Int) -&gt; Duration\n Creates a new duration value of the specified number of whole years,\n assuming a year is 365 days.\n\n ## Example\n \n \n duration.years_imprecise(1)\n |&gt; duration.format\n // -&gt; &quot;1 ~year&quot;\n \nSynonyms:\ntempo/duration.years_imprecise\ntempo/duration years_imprecise","url":"tempo/duration.html#years_imprecise"},{"doc":"tempo/duration","title":"tempo/duration","content":"","url":"tempo/duration.html"},{"doc":"tempo/time","title":"Boundary","content":"pub type Boundary {\n  Boundary(time: tempo.Time, inclusive: Bool)\n}\n\nBoundary(time: tempo.Time, inclusive: Bool)\n\n\nSynonyms:\ntempo/time.Boundary\ntempo/time Boundary","url":"tempo/time.html#Boundary"},{"doc":"tempo/time","title":"add","content":"pub fn add(a: Time, duration b: Duration) -&gt; Time\n Adds a duration to a time.\n \n ## Example\n \n \n time.literal(&quot;08:42:53&quot;)\n |&gt; time.add(duration.mintues(36))\n // -&gt; time.literal(&quot;09:18:53&quot;)\n \nSynonyms:\ntempo/time.add\ntempo/time add","url":"tempo/time.html#add"},{"doc":"tempo/time","title":"compare","content":"pub fn compare(a: Time, to b: Time) -&gt; Order\n Compares two time values.\n \n ## Example\n \n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.compare(to: time.literal(&quot;13:42:11&quot;))\n // -&gt; order.Eq\n \n \n \n time.literal(&quot;15:32:01&quot;)\n |&gt; time.compare(to: time.literal(&quot;13:42:11&quot;))\n // -&gt; order.Gt\n \n \n \n time.literal(&quot;13:10:11&quot;)\n |&gt; time.compare(to: time.literal(&quot;13:42:11&quot;))\n // -&gt; order.Lt\n \nSynonyms:\ntempo/time.compare\ntempo/time compare","url":"tempo/time.html#compare"},{"doc":"tempo/time","title":"difference","content":"pub fn difference(a: Time, from b: Time) -&gt; Duration\n Gets the difference between two times as a duration.\n \n ## Example\n \n \n time.literal(&quot;23:42:11.435&quot;)\n |&gt; time.difference(from: time.literal(&quot;23:42:09.743&quot;))\n |&gt; duration.as_milliseconds\n // -&gt; 1692\n \n \n \n time.literal(&quot;13:30:11&quot;)\n |&gt; time.difference(from: time.literal(&quot;13:55:13&quot;))\n |&gt; duration.as_minutes\n // -&gt; -25\n \nSynonyms:\ntempo/time.difference\ntempo/time difference","url":"tempo/time.html#difference"},{"doc":"tempo/time","title":"difference_abs","content":"pub fn difference_abs(a: Time, from b: Time) -&gt; Duration\n Gets the absolute difference between two times as a duration.\n \n ## Example\n \n \n time.literal(&quot;23:42:11.435&quot;)\n |&gt; time.difference(from: time.literal(&quot;23:42:09.743&quot;))\n |&gt; duration.as_milliseconds\n // -&gt; 1692\n \n \n \n time.literal(&quot;13:30:11&quot;)\n |&gt; time.difference(from: time.literal(&quot;13:55:13&quot;))\n |&gt; duration.as_minutes\n // -&gt; 25\n \nSynonyms:\ntempo/time.difference_abs\ntempo/time difference_abs","url":"tempo/time.html#difference_abs"},{"doc":"tempo/time","title":"from_duration","content":"pub fn from_duration(duration: Duration) -&gt; Time\n Converts a duration to the equivalent time of day, assuming the \n duration epoch is &quot;00:00:00&quot;. Durations longer than 24 hours will be \n wrapped to fit within a 24 hour representation.\n \n ## Example\n \n \n duration.seconds(58)\n |&gt; time.from_duration\n |&gt; time.to_second_precision\n |&gt; time.to_string\n // -&gt; &quot;00:00:58&quot;\n \n \n \n duration.minutes(17)\n |&gt; time.from_duration\n |&gt; time.to_string\n // -&gt; &quot;00:17:00.000000000&quot;\n \n \n \n duration.hours(25)\n |&gt; time.from_duration\n |&gt; time.to_string\n // -&gt; &quot;01:00:00.000000000&quot;\n \n \n \n duration.nanoseconds(-3_000_000_000)\n |&gt; time.from_duration\n |&gt; time.to_string\n // -&gt; &quot;23:59:57.000000000&quot;\n \nSynonyms:\ntempo/time.from_duration\ntempo/time from_duration","url":"tempo/time.html#from_duration"},{"doc":"tempo/time","title":"from_string","content":"pub fn from_string(time: String) -&gt; Result(Time, Error)\n Converts a string to a time value. Accepted formats are `hh:mm:ss.s`, \n `hhmmss.s`, `hh:mm:ss`, `hhmmss`, `hh:mm`, or `hhmm`.\n \n ## Example\n \n \n time.from_string(&quot;00:00:00.000000300&quot;)\n // -&gt; Ok(time.literal(&quot;00:00:00.000000300&quot;))\n \n \n \n time.from_string(&quot;34:54:16&quot;)\n // -&gt; Error(tempo.TimeOutOfBounds)\n \nSynonyms:\ntempo/time.from_string\ntempo/time from_string","url":"tempo/time.html#from_string"},{"doc":"tempo/time","title":"from_tuple","content":"pub fn from_tuple(time: #(Int, Int, Int)) -&gt; Result(Time, Error)\n Converts a tuple of hours, minutes, and seconds to a time value. Useful \n for using with another time library.\n \n ## Example\n \n \n #(13, 42, 11)\n |&gt; time.from_tuple\n // -&gt; time.literal(&quot;13:42:11&quot;)\n \nSynonyms:\ntempo/time.from_tuple\ntempo/time from_tuple","url":"tempo/time.html#from_tuple"},{"doc":"tempo/time","title":"from_tuple_nanosecond","content":"pub fn from_tuple_nanosecond(\n  time: #(Int, Int, Int, Int),\n) -&gt; Result(Time, Error)\n Converts a tuple of hours, minutes, seconds, and nanoseconds to a time \n value. Useful for using with another time library.\n \n ## Example\n \n \n #(13, 42, 11, 872000000)\n |&gt; time.from_tuple_nanosecond\n |&gt; time.to_milli_precision\n // -&gt; time.literal(&quot;13:42:11.872&quot;)\n \nSynonyms:\ntempo/time.from_tuple_nanosecond\ntempo/time from_tuple_nanosecond","url":"tempo/time.html#from_tuple_nanosecond"},{"doc":"tempo/time","title":"is_between","content":"pub fn is_between(\n  time: Time,\n  start: Boundary,\n  and end: Boundary,\n) -&gt; Bool\n Checks if a time is between two boundaries.\n \n ## Example\n\n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.is_between(\n     Boundary(time.literal(&quot;05:00:00&quot;), inclusive: True), \n     and: Boundary(time.literal(&quot;15:00:00&quot;), inclusive: False),\n   )\n // -&gt; True\n \nSynonyms:\ntempo/time.is_between\ntempo/time is_between","url":"tempo/time.html#is_between"},{"doc":"tempo/time","title":"is_earlier","content":"pub fn is_earlier(a: Time, than b: Time) -&gt; Bool\n Checks if the first time is earlier than the second time.\n\n ## Example\n\n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.is_earlier(than: time.literal(&quot;13:42:12&quot;))\n // -&gt; True\n \n\n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.is_earlier(than: time.literal(&quot;13:42:11&quot;))\n // -&gt; False\n \n\n \n time.literal(&quot;13:22:15&quot;)\n |&gt; time.is_earlier(than: time.literal(&quot;07:42:11&quot;))\n // -&gt; False\n \nSynonyms:\ntempo/time.is_earlier\ntempo/time is_earlier","url":"tempo/time.html#is_earlier"},{"doc":"tempo/time","title":"is_earlier_or_equal","content":"pub fn is_earlier_or_equal(a: Time, to b: Time) -&gt; Bool\n Checks if the first time is earlier or equal to the second time.\n\n ## Example\n\n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.is_earlier_or_equal(to: time.literal(&quot;13:42:12&quot;))\n // -&gt; True\n \n\n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.is_earlier_or_equal(to: time.literal(&quot;13:42:11.000&quot;))\n // -&gt; True\n \n\n \n time.literal(&quot;13:22:15&quot;)\n |&gt; time.is_earlier_or_equal(to: time.literal(&quot;07:42:12&quot;))\n // -&gt; False\nSynonyms:\ntempo/time.is_earlier_or_equal\ntempo/time is_earlier_or_equal","url":"tempo/time.html#is_earlier_or_equal"},{"doc":"tempo/time","title":"is_equal","content":"pub fn is_equal(a: Time, to b: Time) -&gt; Bool\n Checks if the first time is equal to the second time.\n\n ## Example\n\n \n time.literal(&quot;13:42:11.000&quot;)\n |&gt; time.is_equal(to: time.literal(&quot;13:42:11&quot;))\n // -&gt; True\n \n\n \n time.literal(&quot;13:42:11.002&quot;)\n |&gt; time.is_equal(to: time.literal(&quot;13:42:11&quot;))\n // -&gt; False\n \nSynonyms:\ntempo/time.is_equal\ntempo/time is_equal","url":"tempo/time.html#is_equal"},{"doc":"tempo/time","title":"is_later","content":"pub fn is_later(a: Time, than b: Time) -&gt; Bool\n Checks if the first time is later than the second time.\n\n ## Example\n\n \n time.literal(&quot;13:22:15&quot;)\n |&gt; time.is_later(than: time.literal(&quot;07:42:11&quot;))\n // -&gt; True\n \n \n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.is_later(than: time.literal(&quot;13:42:12&quot;))\n // -&gt; False\n \n\n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.is_later(than: time.literal(&quot;13:42:11&quot;))\n // -&gt; False\n \nSynonyms:\ntempo/time.is_later\ntempo/time is_later","url":"tempo/time.html#is_later"},{"doc":"tempo/time","title":"is_later_or_equal","content":"pub fn is_later_or_equal(a: Time, to b: Time) -&gt; Bool\n Checks if the first time is earlier or equal to the second time.\n\n ## Example\n\n \n time.literal(&quot;13:22:15&quot;)\n |&gt; time.is_later_or_equal(to: time.literal(&quot;07:42:12&quot;))\n // -&gt; True\n\n \n time.literal(&quot;13:42&quot;)\n |&gt; time.is_later_or_equal(to: time.literal(&quot;13:42:00.000&quot;))\n // -&gt; True\n \n \n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.is_later_or_equal(to: time.literal(&quot;13:42:12&quot;))\n // -&gt; False\n \nSynonyms:\ntempo/time.is_later_or_equal\ntempo/time is_later_or_equal","url":"tempo/time.html#is_later_or_equal"},{"doc":"tempo/time","title":"is_outside","content":"pub fn is_outside(\n  time: Time,\n  start: Boundary,\n  and end: Boundary,\n) -&gt; Bool\n Checks if a time is outside of two boundaries.\n \n ## Example\n\n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.is_outside(\n     time.Boundary(time.literal(&quot;05:00:00&quot;), inclusive: True), \n     and: time.Boundary(time.literal(&quot;15:00:00&quot;), inclusive: False),\n   )\n // -&gt; False\n \nSynonyms:\ntempo/time.is_outside\ntempo/time is_outside","url":"tempo/time.html#is_outside"},{"doc":"tempo/time","title":"left_in_day","content":"pub fn left_in_day(time: Time) -&gt; Time\n Converts a time to the equivalent time left in the day.\n\n ## Example\n\n \n time.literal(&quot;23:59:03&quot;) |&gt; time.left_in_day\n // -&gt; time.literal(&quot;00:00:57&quot;)\n \n\n \n time.literal(&quot;08:05:20&quot;) |&gt; time.left_in_day\n // -&gt; time.literal(&quot;15:54:40&quot;)\n \nSynonyms:\ntempo/time.left_in_day\ntempo/time left_in_day","url":"tempo/time.html#left_in_day"},{"doc":"tempo/time","title":"literal","content":"pub fn literal(time: String) -&gt; Time\n Creates a new time value from a string literal, but will panic if\n the string is invalid. Accepted formats are\n `hh:mm:ss.s`, `hhmmss.s`, `hh:mm:ss`, `hhmmss`, `hh:mm`, or `hhmm`.\n \n Useful for declaring time literals that you know are valid within your \n program.\n \n ## Example\n \n \n case \n   time.now_local() \n   |&gt; time.is_later(than: time.literal(&quot;11:50:00&quot;)) \n { \n   True -&gt; &quot;We are late!&quot;\n   False -&gt; &quot;No rush :)&quot;\n }\n \nSynonyms:\ntempo/time.literal\ntempo/time literal","url":"tempo/time.html#literal"},{"doc":"tempo/time","title":"new","content":"pub fn new(\n  hour: Int,\n  minute: Int,\n  second: Int,\n) -&gt; Result(Time, Error)\n Creates a new time value with second precision.\n \n ## Example\n \n \n time.new(13, 42, 11)\n // -&gt; Ok(time.literal(&quot;13:42:11&quot;))\n \n \n \n time.new(53, 42, 61)\n // -&gt; Error(tempo.TimeOutOfBounds)\n \nSynonyms:\ntempo/time.new\ntempo/time new","url":"tempo/time.html#new"},{"doc":"tempo/time","title":"new_micro","content":"pub fn new_micro(\n  hour: Int,\n  minute: Int,\n  second: Int,\n  microsecond: Int,\n) -&gt; Result(Time, Error)\n Creates a new time value with microsecond precision.\n \n ## Example\n \n \n time.new_micro(13, 42, 11, 20)\n // -&gt; Ok(time.literal(&quot;13:42:11.000020&quot;))\n \n \n \n time.new_micro(13, 42, 11, 200_000)\n // -&gt; Ok(time.literal(&quot;13:42:11.200000&quot;))\n \n \n \n time.new_micro(13, 42, 11, 7_500_000)\n // -&gt; Error(tempo.TimeOutOfBounds)\n \nSynonyms:\ntempo/time.new_micro\ntempo/time new_micro","url":"tempo/time.html#new_micro"},{"doc":"tempo/time","title":"new_milli","content":"pub fn new_milli(\n  hour: Int,\n  minute: Int,\n  second: Int,\n  millisecond: Int,\n) -&gt; Result(Time, Error)\n Creates a new time value with millisecond precision.\n \n ## Example\n \n \n time.new_milli(13, 42, 11, 20)\n // -&gt; Ok(time.literal(&quot;13:42:11.020&quot;))\n \n \n \n time.new_milli(13, 42, 11, 200)\n // -&gt; Ok(time.literal(&quot;13:42:11.200&quot;))\n \n \n \n time.new_milli(13, 42, 11, 7_500)\n // -&gt; Error(tempo.TimeOutOfBounds)\n \nSynonyms:\ntempo/time.new_milli\ntempo/time new_milli","url":"tempo/time.html#new_milli"},{"doc":"tempo/time","title":"new_nano","content":"pub fn new_nano(\n  hour: Int,\n  minute: Int,\n  second: Int,\n  nanosecond: Int,\n) -&gt; Result(Time, Error)\n Creates a new time value with nanosecond precision.\n \n ## Example\n \n \n time.new_nano(13, 42, 11, 20)\n // -&gt; Ok(time.literal(&quot;13:42:11.000000020&quot;))\n \n \n \n time.new_nano(13, 42, 11, 200_000_000)\n // -&gt; Ok(time.literal(&quot;13:42:11.200000000&quot;))\n \n \n \n time.new_nano(13, 42, 11, 7_500_000_000)\n // -&gt; Error(tempo.TimeOutOfBounds)\n \nSynonyms:\ntempo/time.new_nano\ntempo/time new_nano","url":"tempo/time.html#new_nano"},{"doc":"tempo/time","title":"now_local","content":"pub fn now_local() -&gt; Time\n Gets the local time of the host.\n \n ## Example\n \n \n case \n   time.now_local() \n   |&gt; time.is_later(than: time.literal(&quot;11:50:00&quot;)) \n { \n   True -&gt; &quot;We are late!&quot;\n   False -&gt; &quot;No rush :)&quot;\n }\n \nSynonyms:\ntempo/time.now_local\ntempo/time now_local","url":"tempo/time.html#now_local"},{"doc":"tempo/time","title":"now_utc","content":"pub fn now_utc() -&gt; Time\n Gets the UTC time of the host.\n\n ## Example\n \n \n case \n   time.now_utc() \n   |&gt; time.is_later(than: time.literal(&quot;11:50:00&quot;)) \n { \n   True -&gt; &quot;We are all late!&quot;\n   False -&gt; &quot;No rush :)&quot;\n }\n \nSynonyms:\ntempo/time.now_utc\ntempo/time now_utc","url":"tempo/time.html#now_utc"},{"doc":"tempo/time","title":"since","content":"pub fn since(time: Time, since: Time) -&gt; Duration\n Returns a duration representing the time since a given time.\n \n ## Example\n \n \n time.literal(&quot;23:54:00&quot;)\n |&gt; time.since(time.literal(&quot;13:30:04&quot;))\n |&gt; duration.as_hours\n // -&gt; 10\n \n \n \n time.literal(&quot;12:30:54&quot;)\n |&gt; time.since(time.literal(&quot;22:00:00&quot;))\n |&gt; duration.as_milliseconds\n // -&gt; 0\n \nSynonyms:\ntempo/time.since\ntempo/time since","url":"tempo/time.html#since"},{"doc":"tempo/time","title":"subtract","content":"pub fn subtract(a: Time, duration b: Duration) -&gt; Time\n Subtracts a duration from a time.\n \n ## Example\n \n \n time.literal(&quot;13:42:02&quot;)\n |&gt; time.subtract(duration.hours(2))\n // -&gt; time.literal(&quot;11:42:02&quot;)\n \nSynonyms:\ntempo/time.subtract\ntempo/time subtract","url":"tempo/time.html#subtract"},{"doc":"tempo/time","title":"to_duration","content":"pub fn to_duration(time: Time) -&gt; Duration\n Converts a time to duration, assuming the duration epoch is &quot;00:00:00&quot;.\n \n ## Example\n \n \n time.literal(&quot;00:00:00.000000300&quot;)\n |&gt; time.to_duration\n |&gt; duration.as_nanoseconds\n // -&gt; 300\n \n\n \n time.literal(&quot;00:03:06&quot;)\n |&gt; time.to_duration \n |&gt; duration.as_milliseconds\n // -&gt; 186_000\n \nSynonyms:\ntempo/time.to_duration\ntempo/time to_duration","url":"tempo/time.html#to_duration"},{"doc":"tempo/time","title":"to_micro_precision","content":"pub fn to_micro_precision(time: Time) -&gt; Time\n Sets the time to a microsecond precision. Drops any nanoseconds from the\n underlying time value.\n \n ## Example\n \n \n time.literal(&quot;21:53:03.534670892&quot;)\n |&gt; time.to_micro_precision\n |&gt; time.to_string\n // -&gt; &quot;21:53:03.534670&quot;\n \nSynonyms:\ntempo/time.to_micro_precision\ntempo/time to_micro_precision","url":"tempo/time.html#to_micro_precision"},{"doc":"tempo/time","title":"to_milli_precision","content":"pub fn to_milli_precision(time: Time) -&gt; Time\n Sets the time to a millisecond precision. Drops any microseconds from the\n underlying time value.\n \n ## Example\n \n \n time.literal(&quot;21:53:03.530673092&quot;)\n |&gt; time.to_milli_precision\n |&gt; time.to_string\n // -&gt; &quot;21:53:03.530&quot;\n \nSynonyms:\ntempo/time.to_milli_precision\ntempo/time to_milli_precision","url":"tempo/time.html#to_milli_precision"},{"doc":"tempo/time","title":"to_nano_precision","content":"pub fn to_nano_precision(time: Time) -&gt; Time\n Sets the time to a nanosecond precision. Does not alter the underlying \n time value.\n \n ## Example\n \n \n time.literal(&quot;21:53:03.534&quot;)\n |&gt; time.to_nano_precision\n |&gt; time.to_string\n // -&gt; &quot;21:53:03.534000000&quot;\n \nSynonyms:\ntempo/time.to_nano_precision\ntempo/time to_nano_precision","url":"tempo/time.html#to_nano_precision"},{"doc":"tempo/time","title":"to_second_precision","content":"pub fn to_second_precision(time: Time) -&gt; Time\n Sets the time to a second precision. Drops any milliseconds from the\n underlying time value.\n \n ## Example\n \n \n time.literal(&quot;21:53:30.730673092&quot;)\n |&gt; time.to_second_precision\n |&gt; time.to_string\n // -&gt; &quot;21:53:30&quot;\n \nSynonyms:\ntempo/time.to_second_precision\ntempo/time to_second_precision","url":"tempo/time.html#to_second_precision"},{"doc":"tempo/time","title":"to_string","content":"pub fn to_string(time: Time) -&gt; String\n Converts a time value to a string in the format `hh:mm:ss.s`\n \n ## Example\n \n \n time.to_string(my_time)\n |&gt; time.to_string\n // -&gt; &quot;21:53:03.534&quot;\n \nSynonyms:\ntempo/time.to_string\ntempo/time to_string","url":"tempo/time.html#to_string"},{"doc":"tempo/time","title":"to_tuple","content":"pub fn to_tuple(time: Time) -&gt; #(Int, Int, Int)\n Returns a time value as a tuple of hours, minutes, and seconds. Useful \n for using with another time library.\n \n ## Example\n \n \n time.literal(&quot;13:42:11&quot;)\n |&gt; time.to_tuple\n // -&gt; #(13, 42, 11)\n \nSynonyms:\ntempo/time.to_tuple\ntempo/time to_tuple","url":"tempo/time.html#to_tuple"},{"doc":"tempo/time","title":"to_tuple_nanosecond","content":"pub fn to_tuple_nanosecond(time: Time) -&gt; #(Int, Int, Int, Int)\n Returns a time value as a tuple of hours, minutes, seconds, and nanoseconds. \n Useful for using with another time library.\n \n ## Example\n \n \n time.literal(&quot;13:42:11.872&quot;)\n |&gt; time.to_tuple_nanosecond\n // -&gt; #(13, 42, 11, 872000000)\n \nSynonyms:\ntempo/time.to_tuple_nanosecond\ntempo/time to_tuple_nanosecond","url":"tempo/time.html#to_tuple_nanosecond"},{"doc":"tempo/time","title":"until","content":"pub fn until(time: Time, until: Time) -&gt; Duration\n Returns a duration representing the time left until a given time.\n \n ## Example\n \n \n time.literal(&quot;23:54:00&quot;)\n |&gt; time.until(time.literal(&quot;23:59:04&quot;))\n |&gt; duration.as_seconds\n // -&gt; 304\n \n \n \n time.literal(&quot;23:59:03&quot;)\n |&gt; time.until(time.literal(&quot;22:00:00&quot;))\n |&gt; duration.as_milliseconds\n // -&gt; 0\n \nSynonyms:\ntempo/time.until\ntempo/time until","url":"tempo/time.html#until"},{"doc":"tempo/time","title":"tempo/time","content":"","url":"tempo/time.html"},{"doc":"tempo/naive_datetime","title":"add","content":"pub fn add(\n  datetime: NaiveDateTime,\n  duration duration_to_add: Duration,\n) -&gt; NaiveDateTime\n Adds a duration to a naive datetime.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.add(duration.minutes(3))\n // -&gt; naive_datetime.literal(&quot;2024-06-21T23:20:00&quot;)\n \nSynonyms:\ntempo/naive_datetime.add\ntempo/naive_datetime add","url":"tempo/naive_datetime.html#add"},{"doc":"tempo/naive_datetime","title":"compare","content":"pub fn compare(a: NaiveDateTime, to b: NaiveDateTime) -&gt; Order\n Compares two naive datetimes.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.compare(to: naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;))\n // -&gt; order.Eq\n \n \n \n naive_datetime.literal(&quot;2023-05-11T13:15:00&quot;)\n |&gt; naive_datetime.compare(to: naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;))\n // -&gt; order.Lt\n \nSynonyms:\ntempo/naive_datetime.compare\ntempo/naive_datetime compare","url":"tempo/naive_datetime.html#compare"},{"doc":"tempo/naive_datetime","title":"difference","content":"pub fn difference(\n  from a: NaiveDateTime,\n  to b: NaiveDateTime,\n) -&gt; Period\n Returns the difference between two naive datetimes as a period between them.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-12T23:17:00&quot;)\n |&gt; naive_datetime.difference(\n   from: naive_datetime.literal(&quot;2024-06-16T01:16:12&quot;),\n )\n |&gt; period.as_days\n // -&gt; 3\n \n \n \n naive_datetime.literal(&quot;2024-06-12T23:17:00&quot;)\n |&gt; naive_datetime.difference(\n   from: naive_datetime.literal(&quot;2024-06-16T01:18:12&quot;),\n )\n |&gt; period.format\n // -&gt; &quot;3 days, 2 hours, and 1 minute&quot;\n \nSynonyms:\ntempo/naive_datetime.difference\ntempo/naive_datetime difference","url":"tempo/naive_datetime.html#difference"},{"doc":"tempo/naive_datetime","title":"drop_time","content":"pub fn drop_time(datetime: NaiveDateTime) -&gt; NaiveDateTime\n Drops the time of a naive datetime, setting it to zero.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-13T23:17:00&quot;)\n |&gt; naive_datetime.drop_time\n // -&gt; datetime.literal(&quot;2024-06-13T00:00:00&quot;)\n \nSynonyms:\ntempo/naive_datetime.drop_time\ntempo/naive_datetime drop_time","url":"tempo/naive_datetime.html#drop_time"},{"doc":"tempo/naive_datetime","title":"from_string","content":"pub fn from_string(\n  datetime: String,\n) -&gt; Result(NaiveDateTime, Error)\n Parses a naive datetime string in the format `YYYY-MM-DDThh:mm:ss.s`,\n `YYYY-MM-DD hh:mm:ss.s`, `YYYY-MM-DD`, `YYYY-M-D`, `YYYY/MM/DD`, \n `YYYY/M/D`, `YYYY.MM.DD`, `YYYY.M.D`, `YYYY_MM_DD`, `YYYY_M_D`, \n `YYYY MM DD`, `YYYY M D`, or `YYYYMMDD`.\n \n ## Examples\n \n naive_datetime.from_string(&quot;20240612&quot;)\n // -&gt; Ok(naive_datetime.literal(&quot;2024-06-12T00:00:00&quot;))\n \n \n \n naive_datetime.from_string(&quot;2024-06-21 23:17:00&quot;)\n // -&gt; Ok(naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;))\n \n \n \n naive_datetime.from_string(&quot;24-06-12|23:17:00&quot;)\n // -&gt; Error(tempo.NaiveDateTimeInvalidFormat)\n \nSynonyms:\ntempo/naive_datetime.from_string\ntempo/naive_datetime from_string","url":"tempo/naive_datetime.html#from_string"},{"doc":"tempo/naive_datetime","title":"get_date","content":"pub fn get_date(datetime: NaiveDateTime) -&gt; Date\n Gets the date of a naive datetime.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.get_date\n // -&gt; date.literal(&quot;2024-06-21&quot;)\n \nSynonyms:\ntempo/naive_datetime.get_date\ntempo/naive_datetime get_date","url":"tempo/naive_datetime.html#get_date"},{"doc":"tempo/naive_datetime","title":"get_time","content":"pub fn get_time(datetime: NaiveDateTime) -&gt; Time\n Gets the time of a naive datetime.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.get_time\n // -&gt; time.literal(&quot;23:17:00&quot;)\n \nSynonyms:\ntempo/naive_datetime.get_time\ntempo/naive_datetime get_time","url":"tempo/naive_datetime.html#get_time"},{"doc":"tempo/naive_datetime","title":"is_earlier","content":"pub fn is_earlier(\n  a: NaiveDateTime,\n  than b: NaiveDateTime,\n) -&gt; Bool\n Checks if the first naive datetime is earlier than the second naive \n datetime.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.is_earlier(\n   than: naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;),\n )\n // -&gt; False\n \n \n \n naive_datetime.literal(&quot;2013-06-12T23:17:00&quot;)\n |&gt; naive_datetime.is_earlier(\n   than: naive_datetime.literal(&quot;2024-06-12T23:17:00&quot;),\n )\n // -&gt; True\n \nSynonyms:\ntempo/naive_datetime.is_earlier\ntempo/naive_datetime is_earlier","url":"tempo/naive_datetime.html#is_earlier"},{"doc":"tempo/naive_datetime","title":"is_earlier_or_equal","content":"pub fn is_earlier_or_equal(\n  a: NaiveDateTime,\n  to b: NaiveDateTime,\n) -&gt; Bool\n Checks if the first naive datetime is earlier or equal to the second naive \n datetime.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-08-12T23:17:00&quot;)\n |&gt; naive_datetime.is_earlier_or_equal(\n   to: naive_datetime.literal(&quot;2024-06-12T00:00:00&quot;),\n )\n // -&gt; False\n \n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.is_earlier_or_equal(\n   to: naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;),\n )\n // -&gt; True\n \nSynonyms:\ntempo/naive_datetime.is_earlier_or_equal\ntempo/naive_datetime is_earlier_or_equal","url":"tempo/naive_datetime.html#is_earlier_or_equal"},{"doc":"tempo/naive_datetime","title":"is_equal","content":"pub fn is_equal(a: NaiveDateTime, to b: NaiveDateTime) -&gt; Bool\n Checks if the first naive datetime is equal to the second naive datetime.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.is_equal(\n   to: naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;),\n )\n // -&gt; True\n \n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.is_equal(\n   to: naive_datetime.literal(&quot;2024-06-21T23:17:01&quot;),\n )\n // -&gt; False\n \nSynonyms:\ntempo/naive_datetime.is_equal\ntempo/naive_datetime is_equal","url":"tempo/naive_datetime.html#is_equal"},{"doc":"tempo/naive_datetime","title":"is_later","content":"pub fn is_later(a: NaiveDateTime, than b: NaiveDateTime) -&gt; Bool\n Checks if the first naive datetime is later than the second naive datetime.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.is_later(\n   than: naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;),\n )\n // -&gt; False\n \n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.is_later(\n   than: naive_datetime.literal(&quot;2022-04-12T00:00:00&quot;),\n )\n // -&gt; True\n \nSynonyms:\ntempo/naive_datetime.is_later\ntempo/naive_datetime is_later","url":"tempo/naive_datetime.html#is_later"},{"doc":"tempo/naive_datetime","title":"is_later_or_equal","content":"pub fn is_later_or_equal(\n  a: NaiveDateTime,\n  to b: NaiveDateTime,\n) -&gt; Bool\n Checks if the first naive datetime is later or equal to the second naive \n datetime.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.is_later_or_equal(\n   to: naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;),\n )\n // -&gt; True\n \n \n \n naive_datetime.literal(&quot;2022-04-12T00:00:00&quot;)\n |&gt; naive_datetime.is_later_or_equal(\n   to: naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;),\n )\n // -&gt; False\n \nSynonyms:\ntempo/naive_datetime.is_later_or_equal\ntempo/naive_datetime is_later_or_equal","url":"tempo/naive_datetime.html#is_later_or_equal"},{"doc":"tempo/naive_datetime","title":"literal","content":"pub fn literal(naive_datetime: String) -&gt; NaiveDateTime\n Creates a new naive datetime value from a string literal, but will panic \n if the string is invalid.\n \n Useful for declaring date literals that you know are valid within your  \n program.\n\n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:04:00.009&quot;)\n |&gt; naive_datetime.to_string\n // -&gt; &quot;2024-06-21T23:04:00.009&quot;\n \n \n \n naive_datetime.literal(&quot;2024-06-21T23:04:00.009-04:00&quot;)\n // panic\n \nSynonyms:\ntempo/naive_datetime.literal\ntempo/naive_datetime literal","url":"tempo/naive_datetime.html#literal"},{"doc":"tempo/naive_datetime","title":"new","content":"pub fn new(date: Date, time: Time) -&gt; NaiveDateTime\n Creates a new naive datetime from a date and time value.\n \n ## Examples\n \n \n naive_datetime.new(\n   date.literal(&quot;2024-06-21&quot;), \n   time.literal(&quot;23:04:00.009&quot;),\n )\n // -&gt; naive_datetime.literal(&quot;2024-06-21T23:04:00.009&quot;)\n \nSynonyms:\ntempo/naive_datetime.new\ntempo/naive_datetime new","url":"tempo/naive_datetime.html#new"},{"doc":"tempo/naive_datetime","title":"now_local","content":"pub fn now_local() -&gt; NaiveDateTime\n Gets the current local naive datetime of the host.\n \n ## Examples\n \n \n naive_datetime.now_local()\n |&gt; naive_datetime.to_string\n // -&gt; &quot;2024-06-21T12:23:23.380956212&quot;\n \nSynonyms:\ntempo/naive_datetime.now_local\ntempo/naive_datetime now_local","url":"tempo/naive_datetime.html#now_local"},{"doc":"tempo/naive_datetime","title":"now_utc","content":"pub fn now_utc() -&gt; NaiveDateTime\n Gets the current UTC naive datetime of the host.\n \n ## Examples\n \n \n naive_datetime.now_utc()\n |&gt; naive_datetime.to_string\n // -&gt; &quot;2024-06-21T16:23:23.380413364&quot;\n \nSynonyms:\ntempo/naive_datetime.now_utc\ntempo/naive_datetime now_utc","url":"tempo/naive_datetime.html#now_utc"},{"doc":"tempo/naive_datetime","title":"set_offset","content":"pub fn set_offset(\n  datetime: NaiveDateTime,\n  offset: Offset,\n) -&gt; DateTime\n Sets a naive datetime&#39;s offset to the provided offset, leaving the date and\n time unchanged while returning a datetime value. \n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.set_offset(offset.literal(&quot;+10:00&quot;))\n // -&gt; datetime.literal(&quot;2024-06-21T23:17:00+10:00&quot;)\n \nSynonyms:\ntempo/naive_datetime.set_offset\ntempo/naive_datetime set_offset","url":"tempo/naive_datetime.html#set_offset"},{"doc":"tempo/naive_datetime","title":"set_utc","content":"pub fn set_utc(datetime: NaiveDateTime) -&gt; DateTime\n Sets a naive datetime&#39;s offset to UTC, leaving the date and time unchanged\n while returning a datetime value. \n Alias for `set_offset(naive_datetime, offset.utc)`.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.set_utc\n // -&gt; datetime.literal(&quot;2024-06-21T23:17:00Z&quot;)\n \nSynonyms:\ntempo/naive_datetime.set_utc\ntempo/naive_datetime set_utc","url":"tempo/naive_datetime.html#set_utc"},{"doc":"tempo/naive_datetime","title":"subtract","content":"pub fn subtract(\n  datetime: NaiveDateTime,\n  duration duration_to_subtract: Duration,\n) -&gt; NaiveDateTime\n Subtracts a duration from a naive datetime.\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-12T23:17:00&quot;)\n |&gt; naive_datetime.subtract(duration.days(3))\n // -&gt; naive_datetime.literal(&quot;2024-06-09T23:17:00&quot;)\n \nSynonyms:\ntempo/naive_datetime.subtract\ntempo/naive_datetime subtract","url":"tempo/naive_datetime.html#subtract"},{"doc":"tempo/naive_datetime","title":"time_left_in_day","content":"pub fn time_left_in_day(naive_datetime: NaiveDateTime) -&gt; Time\n Gets the time left in the day.\n \n Does **not** account for leap seconds like the rest of the package.\n \n ## Examples\n\n \n naive_datetime.literal(&quot;2015-06-30T23:59:03&quot;)\n |&gt; naive_datetime.time_left_in_day\n // -&gt; time.literal(&quot;00:00:57&quot;)\n \n \n \n naive_datetime.literal(&quot;2024-06-18T08:05:20&quot;)\n |&gt; naive_datetime.time_left_in_day\n // -&gt; time.literal(&quot;15:54:40&quot;)\n \nSynonyms:\ntempo/naive_datetime.time_left_in_day\ntempo/naive_datetime time_left_in_day","url":"tempo/naive_datetime.html#time_left_in_day"},{"doc":"tempo/naive_datetime","title":"to_micro_precision","content":"pub fn to_micro_precision(\n  naive_datetime: NaiveDateTime,\n) -&gt; NaiveDateTime\n Sets a naive datetime&#39;s time value to a microsecond precision. Drops any \n nanoseconds from the underlying time value.\n \n ## Example\n \n \n naive_datetime.literal(&quot;2024-06-13T13:42:11.195423534&quot;)\n |&gt; naive_datetime.to_micro_precision\n |&gt; naive_datetime.to_string\n // -&gt; &quot;2024-06-13T13:42:11.195423&quot;\n \nSynonyms:\ntempo/naive_datetime.to_micro_precision\ntempo/naive_datetime to_micro_precision","url":"tempo/naive_datetime.html#to_micro_precision"},{"doc":"tempo/naive_datetime","title":"to_milli_precision","content":"pub fn to_milli_precision(\n  naive_datetime: NaiveDateTime,\n) -&gt; NaiveDateTime\n Sets a naive datetime&#39;s time value to a millisecond precision. Drops any \n microseconds from the underlying time value.\n \n ## Example\n \n \n naive_datetime.literal(&quot;2024-06-13T13:42:11.195423&quot;)\n |&gt; naive_datetime.to_milli_precision\n |&gt; naive_datetime.to_string\n // -&gt; &quot;2024-06-13T13:42:11.195&quot;\n \nSynonyms:\ntempo/naive_datetime.to_milli_precision\ntempo/naive_datetime to_milli_precision","url":"tempo/naive_datetime.html#to_milli_precision"},{"doc":"tempo/naive_datetime","title":"to_nano_precision","content":"pub fn to_nano_precision(\n  naive_datetime: NaiveDateTime,\n) -&gt; NaiveDateTime\n Sets a naive datetime&#39;s time value to a nanosecond precision. Leaves the\n underlying time value unchanged.\n \n ## Example\n \n \n naive_datetime.literal(&quot;2024-06-13T13:42:11.195&quot;)\n |&gt; naive_datetime.to_nano_precision\n |&gt; naive_datetime.to_string\n // -&gt; &quot;2024-06-13T13:42:11.195000000&quot;\n \nSynonyms:\ntempo/naive_datetime.to_nano_precision\ntempo/naive_datetime to_nano_precision","url":"tempo/naive_datetime.html#to_nano_precision"},{"doc":"tempo/naive_datetime","title":"to_period","content":"pub fn to_period(\n  start start: NaiveDateTime,\n  end end: NaiveDateTime,\n) -&gt; Period\n Creates a period between two naive datetimes.\n \n ## Examples\n \n \n naive_datetime.to_period(\n   start: naive_datetime.literal(&quot;2024-06-12T23:17:00&quot;)\n   end: naive_datetime.literal(&quot;2024-06-16T01:16:12&quot;),\n )\n |&gt; period.as_days\n // -&gt; 3\n \n \n \n naive_datetime.to_period(\n   start: naive_datetime.literal(&quot;2024-06-12T23:17:00&quot;),\n   end: naive_datetime.literal(&quot;2024-06-16T01:18:12&quot;),\n )\n |&gt; period.format\n // -&gt; &quot;3 days, 2 hours, and 1 minute&quot;\n \nSynonyms:\ntempo/naive_datetime.to_period\ntempo/naive_datetime to_period","url":"tempo/naive_datetime.html#to_period"},{"doc":"tempo/naive_datetime","title":"to_second_precision","content":"pub fn to_second_precision(\n  naive_datetime: NaiveDateTime,\n) -&gt; NaiveDateTime\n Sets a naive datetime&#39;s time value to a second precision. Drops any \n milliseconds from the underlying time value.\n \n ## Example\n \n \n naive_datetime.literal(&quot;2024-06-13T13:42:11.195423&quot;)\n |&gt; naive_datetime.to_second_precision\n |&gt; naive_datetime.to_string\n // -&gt; &quot;2024-06-13T13:42:11&quot;\n \nSynonyms:\ntempo/naive_datetime.to_second_precision\ntempo/naive_datetime to_second_precision","url":"tempo/naive_datetime.html#to_second_precision"},{"doc":"tempo/naive_datetime","title":"to_string","content":"pub fn to_string(datetime: NaiveDateTime) -&gt; String\n Returns a string representation of a naive datetime value in the ISO 8601\n format\n \n ## Examples\n \n \n naive_datetime.literal(&quot;2024-06-21T23:17:00&quot;)\n |&gt; naive_datetime.to_string\n // -&gt; &quot;2024-06-21T23:17:00&quot;\n \nSynonyms:\ntempo/naive_datetime.to_string\ntempo/naive_datetime to_string","url":"tempo/naive_datetime.html#to_string"},{"doc":"tempo/naive_datetime","title":"tempo/naive_datetime","content":"","url":"tempo/naive_datetime.html"},{"doc":"tempo/datetime","title":"add","content":"pub fn add(\n  datetime: DateTime,\n  duration duration_to_add: Duration,\n) -&gt; DateTime\n Adds a duration to a datetime.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-12T23:17:00Z&quot;)\n |&gt; datetime.add(duration.minutes(3))\n // -&gt; datetime.literal(&quot;2024-06-12T23:20:00Z&quot;)\n \nSynonyms:\ntempo/datetime.add\ntempo/datetime add","url":"tempo/datetime.html#add"},{"doc":"tempo/datetime","title":"apply_offset","content":"pub fn apply_offset(datetime: DateTime) -&gt; NaiveDateTime\n Applies the offset of a datetime to the date and time values, resulting\n in a new naive datetime value that represents the original datetime in \n UTC time.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T05:36:11.195-04:00&quot;)\n |&gt; datetime.apply_offset\n // -&gt; naive_datetime.literal(&quot;2024-06-21T09:36:11.195&quot;)\n \nSynonyms:\ntempo/datetime.apply_offset\ntempo/datetime apply_offset","url":"tempo/datetime.html#apply_offset"},{"doc":"tempo/datetime","title":"compare","content":"pub fn compare(a: DateTime, to b: DateTime) -&gt; Order\n Compares two datetimes.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T23:47:00+09:05&quot;)\n |&gt; datetime.compare(to: datetime.literal(&quot;2024-06-21T23:47:00+09:05&quot;))\n // -&gt; order.Eq\n \n \n \n datetime.literal(&quot;2023-05-11T13:30:00-04:00&quot;)\n |&gt; datetime.compare(to: datetime.literal(&quot;2023-05-11T13:15:00Z&quot;))\n // -&gt; order.Lt\n \n \n \n datetime.literal(&quot;2024-06-12T23:47:00+09:05&quot;)\n |&gt; datetime.compare(to: datetime.literal(&quot;2022-04-12T00:00:00&quot;))\n // -&gt; order.Gt\n \nSynonyms:\ntempo/datetime.compare\ntempo/datetime compare","url":"tempo/datetime.html#compare"},{"doc":"tempo/datetime","title":"difference","content":"pub fn difference(from a: DateTime, to b: DateTime) -&gt; Period\n Returns the difference between two datetimes as a period between their\n equivalent UTC times.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-12T23:17:00Z&quot;)\n |&gt; datetime.difference(\n   from: datetime.literal(&quot;2024-06-16T01:16:12Z&quot;),\n )\n |&gt; period.as_days\n // -&gt; 3\n \n \n \n datetime.literal(&quot;2024-06-12T23:17:00Z&quot;)\n |&gt; datetime.difference(\n   from: datetime.literal(&quot;2024-06-16T01:18:12Z&quot;),\n )\n |&gt; period.format\n // -&gt; &quot;3 days, 2 hours, and 1 minute&quot;\n \nSynonyms:\ntempo/datetime.difference\ntempo/datetime difference","url":"tempo/datetime.html#difference"},{"doc":"tempo/datetime","title":"drop_offset","content":"pub fn drop_offset(datetime: DateTime) -&gt; NaiveDateTime\n Drops the time of a datetime, leaving the date and time values unchanged.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-13T13:42:11.195Z&quot;)\n |&gt; datetime.drop_offset\n // -&gt; naive_datetime.literal(&quot;2024-06-13T13:42:11&quot;)\n \nSynonyms:\ntempo/datetime.drop_offset\ntempo/datetime drop_offset","url":"tempo/datetime.html#drop_offset"},{"doc":"tempo/datetime","title":"drop_time","content":"pub fn drop_time(datetime: DateTime) -&gt; DateTime\n Drops the time of a datetime, leaving the date value unchanged.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-18T13:42:11.195Z&quot;)\n |&gt; datetime.drop_time\n // -&gt; naive_datetime.literal(&quot;2024-06-18T00:00:00Z&quot;)\n \nSynonyms:\ntempo/datetime.drop_time\ntempo/datetime drop_time","url":"tempo/datetime.html#drop_time"},{"doc":"tempo/datetime","title":"from_dynamic_string","content":"pub fn from_dynamic_string(\n  dynamic_string: Dynamic,\n) -&gt; Result(DateTime, List(DecodeError))\n Checks if a dynamic value is a valid datetime string, and returns the\n datetime if it is.\n \n ## Examples\n \n \n dynamic.from(&quot;2024-06-13T13:42:11.195Z&quot;)\n |&gt; datetime.from_dynamic_string\n // -&gt; Ok(datetime.literal(&quot;2024-06-13T13:42:11.195Z&quot;))\n \n \n \n dynamic.from(&quot;24-06-13,13:42:11.195&quot;)\n |&gt; datetime.from_dynamic_string\n // -&gt; Error([\n //   dynamic.DecodeError(\n //     expected: &quot;tempo.DateTime&quot;,\n //     found: &quot;Invalid format: 24-06-13,13:42:11.195&quot;,\n //     path: [],\n //   ),\n // ])\n \nSynonyms:\ntempo/datetime.from_dynamic_string\ntempo/datetime from_dynamic_string","url":"tempo/datetime.html#from_dynamic_string"},{"doc":"tempo/datetime","title":"from_dynamic_unix_micro_utc","content":"pub fn from_dynamic_unix_micro_utc(\n  dynamic_ts: Dynamic,\n) -&gt; Result(DateTime, List(DecodeError))\n Checks if a dynamic value is a valid unix timestamp in microseconds, and \n returns the datetime if it is.\n \n ## Examples\n \n \n dynamic.from(1_718_629_314_334_734)\n |&gt; datetime.from_dynamic_unix_utc\n // -&gt; Ok(datetime.literal(&quot;2024-06-17T13:01:54.334734Z&quot;))\n \n \n \n dynamic.from(&quot;hello&quot;)\n |&gt; datetime.from_dynamic_unix_utc\n // -&gt; Error([\n //   dynamic.DecodeError(\n //     expected: &quot;Int&quot;,\n //     found: &quot;String&quot;,\n //     path: [],\n //   ),\n // ])\n \nSynonyms:\ntempo/datetime.from_dynamic_unix_micro_utc\ntempo/datetime from_dynamic_unix_micro_utc","url":"tempo/datetime.html#from_dynamic_unix_micro_utc"},{"doc":"tempo/datetime","title":"from_dynamic_unix_milli_utc","content":"pub fn from_dynamic_unix_milli_utc(\n  dynamic_ts: Dynamic,\n) -&gt; Result(DateTime, List(DecodeError))\n Checks if a dynamic value is a valid unix timestamp in milliseconds, and \n returns the datetime if it is.\n \n ## Examples\n \n \n dynamic.from(1_718_629_314_334)\n |&gt; datetime.from_dynamic_unix_utc\n // -&gt; Ok(datetime.literal(&quot;2024-06-17T13:01:54.334Z&quot;))\n \n \n \n dynamic.from(&quot;hello&quot;)\n |&gt; datetime.from_dynamic_unix_utc\n // -&gt; Error([\n //   dynamic.DecodeError(\n //     expected: &quot;Int&quot;,\n //     found: &quot;String&quot;,\n //     path: [],\n //   ),\n // ])\n \nSynonyms:\ntempo/datetime.from_dynamic_unix_milli_utc\ntempo/datetime from_dynamic_unix_milli_utc","url":"tempo/datetime.html#from_dynamic_unix_milli_utc"},{"doc":"tempo/datetime","title":"from_dynamic_unix_utc","content":"pub fn from_dynamic_unix_utc(\n  dynamic_ts: Dynamic,\n) -&gt; Result(DateTime, List(DecodeError))\n Checks if a dynamic value is a valid unix timestamp in seconds, and \n returns the datetime if it is.\n \n ## Examples\n \n \n dynamic.from(1_718_629_314)\n |&gt; datetime.from_dynamic_unix_utc\n // -&gt; Ok(datetime.literal(&quot;2024-06-17T13:01:54Z&quot;))\n \n \n \n dynamic.from(&quot;hello&quot;)\n |&gt; datetime.from_dynamic_unix_utc\n // -&gt; Error([\n //   dynamic.DecodeError(\n //     expected: &quot;Int&quot;,\n //     found: &quot;String&quot;,\n //     path: [],\n //   ),\n // ])\n \nSynonyms:\ntempo/datetime.from_dynamic_unix_utc\ntempo/datetime from_dynamic_unix_utc","url":"tempo/datetime.html#from_dynamic_unix_utc"},{"doc":"tempo/datetime","title":"from_string","content":"pub fn from_string(datetime: String) -&gt; Result(DateTime, Error)\n Parses a datetime string in the format `YYYY-MM-DDThh:mm:ss.sTZD`,\n `YYYYMMDDThhmmss.sTZD`, `YYYY-MM-DD hh:mm:ss.sTZD`,\n `YYYYMMDD hhmmss.sTZD`, `YYYY-MM-DD`, `YYYY-M-D`, `YYYY/MM/DD`, \n `YYYY/M/D`, `YYYY.MM.DD`, `YYYY.M.D`, `YYYY_MM_DD`, `YYYY_M_D`, \n `YYYY MM DD`, `YYYY M D`, or `YYYYMMDD`.\n \n ## Examples\n \n \n datetime.from_string(&quot;20240613T230400.009+00:00&quot;)\n // -&gt; datetime.literal(&quot;2024-06-13T23:04:00.009Z&quot;)\n \nSynonyms:\ntempo/datetime.from_string\ntempo/datetime from_string","url":"tempo/datetime.html#from_string"},{"doc":"tempo/datetime","title":"from_unix_micro_utc","content":"pub fn from_unix_micro_utc(unix_ts: Int) -&gt; DateTime\n Returns the UTC datetime of a unix timestamp in microseconds.\n \n ## Examples\n \n \n datetime.from_unix_micro_utc(1_718_629_314_334_734)\n // -&gt; datetime.literal(&quot;2024-06-17T13:01:54.334734Z&quot;)\n \nSynonyms:\ntempo/datetime.from_unix_micro_utc\ntempo/datetime from_unix_micro_utc","url":"tempo/datetime.html#from_unix_micro_utc"},{"doc":"tempo/datetime","title":"from_unix_milli_utc","content":"pub fn from_unix_milli_utc(unix_ts: Int) -&gt; DateTime\n Returns the UTC datetime of a unix timestamp in milliseconds.\n \n ## Examples\n \n \n datetime.from_unix_milli_utc(1_718_629_314_334)\n // -&gt; datetime.literal(&quot;2024-06-17T13:01:54.334Z&quot;)\n \nSynonyms:\ntempo/datetime.from_unix_milli_utc\ntempo/datetime from_unix_milli_utc","url":"tempo/datetime.html#from_unix_milli_utc"},{"doc":"tempo/datetime","title":"from_unix_utc","content":"pub fn from_unix_utc(unix_ts: Int) -&gt; DateTime\n Returns the UTC datetime of a unix timestamp.\n \n ## Examples\n \n \n datetime.from_unix_utc(1_718_829_191)\n // -&gt; datetime.literal(&quot;2024-06-17T12:59:51Z&quot;)\n \nSynonyms:\ntempo/datetime.from_unix_utc\ntempo/datetime from_unix_utc","url":"tempo/datetime.html#from_unix_utc"},{"doc":"tempo/datetime","title":"get_date","content":"pub fn get_date(datetime: DateTime) -&gt; Date\n Gets the date of a datetime.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T13:42:11.195Z&quot;)\n |&gt; datetime.get_date\n // -&gt; date.literal(&quot;2024-06-21&quot;)\n \nSynonyms:\ntempo/datetime.get_date\ntempo/datetime get_date","url":"tempo/datetime.html#get_date"},{"doc":"tempo/datetime","title":"get_offset","content":"pub fn get_offset(datetime: DateTime) -&gt; Offset\n Gets the offset of a datetime.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-12T13:42:11.195-04:00&quot;)\n |&gt; datetime.get_offset\n // -&gt; offset.literal(&quot;+04:00&quot;)\n \nSynonyms:\ntempo/datetime.get_offset\ntempo/datetime get_offset","url":"tempo/datetime.html#get_offset"},{"doc":"tempo/datetime","title":"get_time","content":"pub fn get_time(datetime: DateTime) -&gt; Time\n Gets the time of a datetime.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T13:42:11.195Z&quot;)\n |&gt; datetime.get_time\n // -&gt; time.literal(&quot;13:42:11.195&quot;)\n \nSynonyms:\ntempo/datetime.get_time\ntempo/datetime get_time","url":"tempo/datetime.html#get_time"},{"doc":"tempo/datetime","title":"is_earlier","content":"pub fn is_earlier(a: DateTime, than b: DateTime) -&gt; Bool\n Checks if the first datetime is earlier than the second datetime.\n\n ## Examples\n\n \n datetime.literal(&quot;2024-06-21T23:47:00+09:05&quot;)\n |&gt; datetime.is_earlier(\n   than: datetime.literal(&quot;2024-06-21T23:47:00+09:05&quot;),\n )\n // -&gt; False\n \n\n \n datetime.literal(&quot;2023-05-11T13:30:00-04:00&quot;)\n |&gt; datetime.is_earlier(\n   than: datetime.literal(&quot;2023-05-11T13:15:00Z&quot;),\n )\n // -&gt; True\n \nSynonyms:\ntempo/datetime.is_earlier\ntempo/datetime is_earlier","url":"tempo/datetime.html#is_earlier"},{"doc":"tempo/datetime","title":"is_earlier_or_equal","content":"pub fn is_earlier_or_equal(a: DateTime, to b: DateTime) -&gt; Bool\n Checks if the first datetime is earlier or equal to the second datetime.\n \n ## Examples\n \n datetime.literal(&quot;2024-06-21T23:47:00+09:05&quot;)\n |&gt; datetime.is_earlier_or_equal(\n   to: datetime.literal(&quot;2024-06-21T23:47:00+09:05&quot;),\n )\n // -&gt; True\n \n \n \n datetime.literal(&quot;2024-07-15T23:40:00-04:00&quot;)\n |&gt; datetime.is_earlier_or_equal(\n   to: datetime.literal(&quot;2023-05-11T13:15:00Z&quot;),\n )\n // -&gt; False\n \nSynonyms:\ntempo/datetime.is_earlier_or_equal\ntempo/datetime is_earlier_or_equal","url":"tempo/datetime.html#is_earlier_or_equal"},{"doc":"tempo/datetime","title":"is_equal","content":"pub fn is_equal(a: DateTime, to b: DateTime) -&gt; Bool\n Checks if the first datetime is equal to the second datetime.\n \n ## Examples\n \n datetime.literal(&quot;2024-06-21T09:44:00Z&quot;)\n |&gt; datetime.is_equal(\n   to: datetime.literal(&quot;2024-06-21T05:44:00-04:00&quot;),\n )\n // -&gt; True\n \n \n \n datetime.literal(&quot;2024-06-21T09:44:00Z&quot;)\n |&gt; datetime.is_equal(\n   to: datetime.literal(&quot;2024-06-21T09:44:00.045Z&quot;),\n )\n // -&gt; False\n \nSynonyms:\ntempo/datetime.is_equal\ntempo/datetime is_equal","url":"tempo/datetime.html#is_equal"},{"doc":"tempo/datetime","title":"is_later","content":"pub fn is_later(a: DateTime, than b: DateTime) -&gt; Bool\n Checks if the first datetime is later than the second datetime.\n\n ## Examples\n\n \n datetime.literal(&quot;2024-06-21T23:47:00+09:05&quot;)\n |&gt; datetime.is_later(\n   than: datetime.literal(&quot;2024-06-21T23:47:00+09:05&quot;),\n )\n // -&gt; False\n \n\n \n datetime.literal(&quot;2023-05-11T13:00:00+04:00&quot;)\n |&gt; datetime.is_later(\n   than: datetime.literal(&quot;2023-05-11T13:15:00.534Z&quot;),\n )\n // -&gt; True\n \nSynonyms:\ntempo/datetime.is_later\ntempo/datetime is_later","url":"tempo/datetime.html#is_later"},{"doc":"tempo/datetime","title":"is_later_or_equal","content":"pub fn is_later_or_equal(a: DateTime, to b: DateTime) -&gt; Bool\n Checks if the first datetime is later or equal to the second datetime.\n \n ## Examples\n \n datetime.literal(&quot;2016-01-11T03:47:00+09:05&quot;)\n |&gt; datetime.is_later_or_equal(\n   to: datetime.literal(&quot;2024-06-21T23:47:00+09:05&quot;),\n )\n // -&gt; False\n \n \n \n datetime.literal(&quot;2024-07-15T23:40:00-04:00&quot;)\n |&gt; datetime.is_later_or_equal(\n   to: datetime.literal(&quot;2023-05-11T13:15:00Z&quot;),\n )\n // -&gt; True\n \nSynonyms:\ntempo/datetime.is_later_or_equal\ntempo/datetime is_later_or_equal","url":"tempo/datetime.html#is_later_or_equal"},{"doc":"tempo/datetime","title":"literal","content":"pub fn literal(datetime: String) -&gt; DateTime\n Create a new datetime value from a string literal, but will panic if\n the string is invalid. Accepted formats are `YYYY-MM-DDThh:mm:ss.sTZD` or\n `YYYYMMDDThhmmss.sTZD`\n \n Useful for declaring datetime literals that you know are valid within your  \n program.\n\n ## Examples\n \n \n datetime.literal(&quot;2024-06-13T23:04:00.009+10:00&quot;)\n |&gt; datetime.to_string\n // -&gt; &quot;2024-06-13T23:04:00.009+10:00&quot;\n \nSynonyms:\ntempo/datetime.literal\ntempo/datetime literal","url":"tempo/datetime.html#literal"},{"doc":"tempo/datetime","title":"new","content":"pub fn new(\n  date date: Date,\n  time time: Time,\n  offset offset: Offset,\n) -&gt; DateTime\n Create a new datetime from a date, time, and offset.\n \n ## Examples\n \n \n datetime.new(\n   date.literal(&quot;2024-06-13&quot;), \n   time.literal(&quot;23:04:00.009&quot;),\n   offset.literal(&quot;+10:00&quot;),\n )\n // -&gt; datetime.literal(&quot;2024-06-13T23:04:00.009+10:00&quot;)\n \nSynonyms:\ntempo/datetime.new\ntempo/datetime new","url":"tempo/datetime.html#new"},{"doc":"tempo/datetime","title":"now_local","content":"pub fn now_local() -&gt; DateTime\n Gets the current local datetime of the host.\n \n ## Examples\n \n \n datetime.now()\n |&gt; datetime.to_string\n // -&gt; &quot;2024-06-14T04:19:20.006809349-04:00&quot;\n \nSynonyms:\ntempo/datetime.now_local\ntempo/datetime now_local","url":"tempo/datetime.html#now_local"},{"doc":"tempo/datetime","title":"now_text","content":"pub fn now_text() -&gt; String\n Gets the current local datetime of the host as a string in milliseconds\n precision. For easy reading by humans in text formats, like log \n statements, etc.\n \n ## Examples\n \n \n datetime.now_text()\n // -&gt; &quot;2024-06-14 04:19:20.349&quot;\n \nSynonyms:\ntempo/datetime.now_text\ntempo/datetime now_text","url":"tempo/datetime.html#now_text"},{"doc":"tempo/datetime","title":"now_utc","content":"pub fn now_utc() -&gt; DateTime\n Gets the current UTC datetime of the host.\n \n ## Examples\n \n \n datetime.now_utc()\n |&gt; datetime.to_string\n // -&gt; &quot;2024-06-14T08:19:20.006809349Z&quot;\n \nSynonyms:\ntempo/datetime.now_utc\ntempo/datetime now_utc","url":"tempo/datetime.html#now_utc"},{"doc":"tempo/datetime","title":"subtract","content":"pub fn subtract(\n  datetime: DateTime,\n  duration duration_to_subtract: Duration,\n) -&gt; DateTime\n Subtracts a duration from a datetime.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T23:17:00Z&quot;)\n |&gt; datetime.subtract(duration.days(3))\n // -&gt; datetime.literal(&quot;2024-06-18T23:17:00Z&quot;)\n \nSynonyms:\ntempo/datetime.subtract\ntempo/datetime subtract","url":"tempo/datetime.html#subtract"},{"doc":"tempo/datetime","title":"time_left_in_day","content":"pub fn time_left_in_day(datetime: DateTime) -&gt; Time\n Gets the time left in the day.\n \n Does **not** account for leap seconds like the rest of the package.\n \n ## Examples\n\n \n naive_datetime.literal(&quot;2015-06-30T23:59:03Z&quot;)\n |&gt; naive_datetime.time_left_in_day\n // -&gt; time.literal(&quot;00:00:57&quot;)\n \n \n \n naive_datetime.literal(&quot;2024-06-18T08:05:20-04:00&quot;)\n |&gt; naive_datetime.time_left_in_day\n // -&gt; time.literal(&quot;15:54:40&quot;)\n \nSynonyms:\ntempo/datetime.time_left_in_day\ntempo/datetime time_left_in_day","url":"tempo/datetime.html#time_left_in_day"},{"doc":"tempo/datetime","title":"to_local","content":"pub fn to_local(\n  datetime: DateTime,\n) -&gt; UncertainConversion(DateTime)\n Converts a datetime to the equivalent local datetime. The return value\n indicates if the conversion was precise or imprecise. Use mattern\n matching to handle the two cases.\n \n Conversion is based on the host&#39;s current offset. If the date of the\n supplied datetime matches the date of the host, then we can apply the\n current host&#39;s offset to get the local time safely, resulting in a precise\n conversion. If the date does not match the host&#39;s, then we can not be \n sure the current offset is still applicable, and will perform an \n imprecise conversion. The imprecise conversion can be inaccurate to the\n degree the local offset changes throughout the year. For example, in \n North America where Daylight Savings Time is observed with a one-hour\n time shift, the imprecise conversion can be off by up to an hour depending\n on the time of year.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T09:57:11.195Z&quot;)\n |&gt; datetime.to_local\n // -&gt; tempo.Precise(datetime.literal(&quot;2024-06-21T05:57:11.195-04:00&quot;))\n \n \n \n datetime.literal(&quot;1998-08-23T09:57:11.195Z&quot;)\n |&gt; datetime.to_local\n // -&gt; tempo.Imprecise(datetime.literal(&quot;1998-08-23T05:57:11.195-04:00&quot;))\n \nSynonyms:\ntempo/datetime.to_local\ntempo/datetime to_local","url":"tempo/datetime.html#to_local"},{"doc":"tempo/datetime","title":"to_local_date","content":"pub fn to_local_date(\n  datetime: DateTime,\n) -&gt; UncertainConversion(Date)\n Converts a datetime to the equivalent local time. The return value\n indicates if the conversion was precise or imprecise. Use mattern\n matching to handle the two cases.\n \n Conversion is based on the host&#39;s current offset. If the date of the\n supplied datetime matches the date of the host, then we can apply the\n current host&#39;s offset to get the local time safely, resulting in a precise\n conversion. If the date does not match the host&#39;s, then we can not be \n sure the current offset is still applicable, and will perform an \n imprecise conversion. The imprecise conversion can be inaccurate to the\n degree the local offset changes throughout the year. For example, in \n North America where Daylight Savings Time is observed with a one-hour\n time shift, the imprecise conversion can be off by up to an hour depending\n on the time of year.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-19T01:35:11.195Z&quot;)\n |&gt; datetime.to_local_date\n // -&gt; tempo.Precise(date.literal(&quot;2024-06-18&quot;))\n \n \n \n datetime.literal(&quot;1998-08-23T01:57:11.195Z&quot;)\n |&gt; datetime.to_local_date\n // -&gt; tempo.Imprecise(date.literal(&quot;1998-08-22&quot;))\n \nSynonyms:\ntempo/datetime.to_local_date\ntempo/datetime to_local_date","url":"tempo/datetime.html#to_local_date"},{"doc":"tempo/datetime","title":"to_local_time","content":"pub fn to_local_time(\n  datetime: DateTime,\n) -&gt; UncertainConversion(Time)\n Converts a datetime to the equivalent local time. The return value\n indicates if the conversion was precise or imprecise. Use mattern\n matching to handle the two cases.\n \n Conversion is based on the host&#39;s current offset. If the date of the\n supplied datetime matches the date of the host, then we can apply the\n current host&#39;s offset to get the local time safely, resulting in a precise\n conversion. If the date does not match the host&#39;s, then we can not be \n sure the current offset is still applicable, and will perform an \n imprecise conversion. The imprecise conversion can be inaccurate to the\n degree the local offset changes throughout the year. For example, in \n North America where Daylight Savings Time is observed with a one-hour\n time shift, the imprecise conversion can be off by up to an hour depending\n on the time of year.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T09:57:11.195Z&quot;)\n |&gt; datetime.to_local_time\n // -&gt; tempo.Precise(time.literal(&quot;05:57:11.195&quot;))\n \n \n \n datetime.literal(&quot;1998-08-23T09:57:11.195Z&quot;)\n |&gt; datetime.to_local_time\n // -&gt; tempo.Imprecise(time.literal(&quot;05:57:11.195&quot;))\n \nSynonyms:\ntempo/datetime.to_local_time\ntempo/datetime to_local_time","url":"tempo/datetime.html#to_local_time"},{"doc":"tempo/datetime","title":"to_micro_precision","content":"pub fn to_micro_precision(datetime: DateTime) -&gt; DateTime\n Sets a datetime&#39;s time value to a microsecond precision. Drops any \n nanoseconds from the underlying time value.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-13T13:42:11.195423534Z&quot;)\n |&gt; datetime.to_micro_precision\n |&gt; datetime.to_string\n // -&gt; &quot;2024-06-13T13:42:11.195423Z&quot;\n \nSynonyms:\ntempo/datetime.to_micro_precision\ntempo/datetime to_micro_precision","url":"tempo/datetime.html#to_micro_precision"},{"doc":"tempo/datetime","title":"to_milli_precision","content":"pub fn to_milli_precision(datetime: DateTime) -&gt; DateTime\n Sets a datetime&#39;s time value to a millisecond precision. Drops any \n microseconds from the underlying time value.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-13T13:42:11.195423Z&quot;)\n |&gt; datetime.to_milli_precision\n |&gt; datetime.to_string\n // -&gt; &quot;2024-06-13T13:42:11.195Z&quot;\n \nSynonyms:\ntempo/datetime.to_milli_precision\ntempo/datetime to_milli_precision","url":"tempo/datetime.html#to_milli_precision"},{"doc":"tempo/datetime","title":"to_nano_precision","content":"pub fn to_nano_precision(datetime: DateTime) -&gt; DateTime\n Sets a datetime&#39;s time value to a nanosecond precision. Leaves the\n underlying time value unchanged.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-13T13:42:11.195Z&quot;)\n |&gt; datetime.to_nano_precision\n |&gt; datetime.to_string\n // -&gt; &quot;2024-06-13T13:42:11.195000000Z&quot;\n \nSynonyms:\ntempo/datetime.to_nano_precision\ntempo/datetime to_nano_precision","url":"tempo/datetime.html#to_nano_precision"},{"doc":"tempo/datetime","title":"to_offset","content":"pub fn to_offset(datetime: DateTime, offset: Offset) -&gt; DateTime\n Converts a datetime to the equivalent time in an offset.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T05:36:11.195-04:00&quot;)\n |&gt; datetime.to_offset(offset.literal(&quot;+10:00&quot;))\n // -&gt; datetime.literal(&quot;2024-06-21T19:36:11.195+10:00&quot;)\n \nSynonyms:\ntempo/datetime.to_offset\ntempo/datetime to_offset","url":"tempo/datetime.html#to_offset"},{"doc":"tempo/datetime","title":"to_period","content":"pub fn to_period(\n  start start: DateTime,\n  end end: DateTime,\n) -&gt; Period\n Creates a period between two datetimes, where the start and end times are\n the equivalent UTC times of the provided datetimes.\n \n ## Examples\n \n \n datetime.to_period(\n   start: datetime.literal(&quot;2024-06-12T23:17:00Z&quot;)\n   end: datetime.literal(&quot;2024-06-16T01:16:12Z&quot;),\n )\n |&gt; period.as_days\n // -&gt; 3\n \n \n \n datetime.to_period(\n   start: datetime.literal(&quot;2024-06-12T23:17:00Z&quot;)\n   end: datetime.literal(&quot;2024-06-16T01:18:12Z&quot;),\n )\n |&gt; period.format\n // -&gt; &quot;3 days, 2 hours, and 1 minute&quot;\n \nSynonyms:\ntempo/datetime.to_period\ntempo/datetime to_period","url":"tempo/datetime.html#to_period"},{"doc":"tempo/datetime","title":"to_second_precision","content":"pub fn to_second_precision(datetime: DateTime) -&gt; DateTime\n Sets a datetime&#39;s time value to a second precision. Drops any milliseconds\n from the underlying time value.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-13T13:42:11.195423Z&quot;)\n |&gt; datetime.to_second_precision\n |&gt; datetime.to_string\n // -&gt; &quot;2024-06-13T13:42:11Z&quot;\n \nSynonyms:\ntempo/datetime.to_second_precision\ntempo/datetime to_second_precision","url":"tempo/datetime.html#to_second_precision"},{"doc":"tempo/datetime","title":"to_string","content":"pub fn to_string(datetime: DateTime) -&gt; String\n Returns a string representation of a datetime value in the ISO 8601\n format.\n \n ## Examples\n \n \n datetime.now_utc()\n |&gt; datetime.to_string\n // -&gt; &quot;2024-06-21T05:22:22.009Z&quot; \n \nSynonyms:\ntempo/datetime.to_string\ntempo/datetime to_string","url":"tempo/datetime.html#to_string"},{"doc":"tempo/datetime","title":"to_unix_micro_utc","content":"pub fn to_unix_micro_utc(datetime: DateTime) -&gt; Int\n Returns the UTC unix timestamp in microseconds of a datetime.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-17T13:01:54.334734Z&quot;)\n |&gt; datetime.to_unix_micro_utc\n // -&gt; 1_718_629_314_334_734\n \nSynonyms:\ntempo/datetime.to_unix_micro_utc\ntempo/datetime to_unix_micro_utc","url":"tempo/datetime.html#to_unix_micro_utc"},{"doc":"tempo/datetime","title":"to_unix_milli_utc","content":"pub fn to_unix_milli_utc(datetime: DateTime) -&gt; Int\n Returns the UTC unix timestamp in milliseconds of a datetime.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-17T13:01:54.334Z&quot;)\n |&gt; datetime.to_unix_milli_utc\n // -&gt; 1_718_629_314_334\n \nSynonyms:\ntempo/datetime.to_unix_milli_utc\ntempo/datetime to_unix_milli_utc","url":"tempo/datetime.html#to_unix_milli_utc"},{"doc":"tempo/datetime","title":"to_unix_utc","content":"pub fn to_unix_utc(datetime: DateTime) -&gt; Int\n Returns the UTC unix timestamp of a datetime.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-17T12:59:51Z&quot;)\n |&gt; datetime.to_unix_utc\n // -&gt; 1_718_829_191\n \nSynonyms:\ntempo/datetime.to_unix_utc\ntempo/datetime to_unix_utc","url":"tempo/datetime.html#to_unix_utc"},{"doc":"tempo/datetime","title":"to_utc","content":"pub fn to_utc(datetime: DateTime) -&gt; DateTime\n Converts a datetime to the equivalent UTC time.\n \n ## Examples\n \n \n datetime.literal(&quot;2024-06-21T05:36:11.195-04:00&quot;)\n |&gt; datetime.to_utc\n // -&gt; datetime.literal(&quot;2024-06-21T09:36:11.195Z&quot;)\n \nSynonyms:\ntempo/datetime.to_utc\ntempo/datetime to_utc","url":"tempo/datetime.html#to_utc"},{"doc":"tempo/datetime","title":"tempo/datetime","content":"","url":"tempo/datetime.html"},{"doc":"tempo/period","title":"Unit","content":"pub type Unit {\n  Year\n  Month\n  Week\n  Day\n  Hour\n  Minute\n  Second\n  Millisecond\n  Microsecond\n  Nanosecond\n}\n\nYear\n\n\nMonth\n\n\nWeek\n\n\nDay\n\n\nHour\n\n\nMinute\n\n\nSecond\n\n\nMillisecond\n\n\nMicrosecond\n\n\nNanosecond\n\n\nSynonyms:\ntempo/period.Unit\ntempo/period Unit","url":"tempo/period.html#Unit"},{"doc":"tempo/period","title":"as_days","content":"pub fn as_days(period: Period) -&gt; Int\n Returns the number of days in the period.\n \n ## Examples\n \n \n period.new(\n   start: naive_datetime.literal(&quot;2024-06-13T15:47:00&quot;),\n   end: naive_datetime.literal(&quot;2024-06-21T07:16:12&quot;),\n )\n |&gt; period.as_days\n // -&gt; 7\n \nSynonyms:\ntempo/period.as_days\ntempo/period as_days","url":"tempo/period.html#as_days"},{"doc":"tempo/period","title":"as_days_fractional","content":"pub fn as_days_fractional(period: Period) -&gt; Float\n Returns the number of days in the period.\n \n Does **not** account for leap seconds like the rest of the package.\n \n ## Examples\n \n \n period.new(\n   start: naive_datetime.literal(&quot;2024-06-13T15:47:00&quot;),\n   end: naive_datetime.literal(&quot;2024-06-21T07:16:12&quot;),\n )\n |&gt; period.as_days_fractional\n // -&gt; 7.645277777777778\n \nSynonyms:\ntempo/period.as_days_fractional\ntempo/period as_days_fractional","url":"tempo/period.html#as_days_fractional"},{"doc":"tempo/period","title":"as_duration","content":"pub fn as_duration(period: Period) -&gt; Duration\n Returns a period as a duration, losing the context of the start and end \n datetimes.\n \n ## Example\n \n \n period.new(\n   start: naive_datetime.literal(&quot;2024-06-13T15:47:00&quot;),\n   end: naive_datetime.literal(&quot;2024-06-21T07:16:12&quot;),\n )\n |&gt; period.as_duration\n |&gt; duration.as_weeks\n // -&gt; 1\n \nSynonyms:\ntempo/period.as_duration\ntempo/period as_duration","url":"tempo/period.html#as_duration"},{"doc":"tempo/period","title":"as_seconds","content":"pub fn as_seconds(period: Period) -&gt; Int\n Returns the number of seconds in the period.\n \n Does **not** account for leap seconds like the rest of the package.\n \n ## Examples\n \n \n period.new(\n   start: naive_datetime.literal(&quot;2024-06-13T07:16:32&quot;),\n   end: naive_datetime.literal(&quot;2024-06-13T07:16:12&quot;),\n )\n |&gt; period.as_seconds\n // -&gt; 20\n \nSynonyms:\ntempo/period.as_seconds\ntempo/period as_seconds","url":"tempo/period.html#as_seconds"},{"doc":"tempo/period","title":"new","content":"pub fn new(\n  start start: NaiveDateTime,\n  end end: NaiveDateTime,\n) -&gt; Period\n Creates a new period from the start and end naive datetimes.\n \n ## Examples\n \n \n period.new(\n   start: naive_datetime.literal(&quot;2024-06-13T15:47:00&quot;),\n   end: naive_datetime.literal(&quot;2024-06-21T07:16:12&quot;),\n )\n |&gt; period.as_days\n // -&gt; 7\n \nSynonyms:\ntempo/period.new\ntempo/period new","url":"tempo/period.html#new"},{"doc":"tempo/period","title":"to_duration","content":"pub fn to_duration(period: Period) -&gt; Duration\n\nSynonyms:\ntempo/period.to_duration\ntempo/period to_duration","url":"tempo/period.html#to_duration"},{"doc":"tempo/period","title":"tempo/period","content":"","url":"tempo/period.html"}]);